<?php
/**
 * NewsFort functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package NewsFort
 */


if ( ! function_exists( 'newsfort_after_theme_support' ) ) :

	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */

	function newsfort_after_theme_support() {

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		// Custom background color.
		add_theme_support('custom-background', apply_filters('newsfort_custom_background_args', array(
            'default-color' => 'ffffff',
            'default-image' => '',
        )));

		// This variable is intended to be overruled from themes.
		// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
		// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
		$GLOBALS['content_width'] = apply_filters( 'newsfort_content_width', 1140 );
		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size('newsfort-150-150',75,75,true);
		add_image_size('newsfort-500-300',500,300,true);
		add_image_size('newsfort-400-280',400,280,true);
		add_image_size('newsfort-400-500',400,500,true);
		add_image_size('newsfort-550-400',550,400,true);
		add_image_size('newsfort-1600-700',1600,700,true);

		add_theme_support(
			'custom-logo',
			array(
				'height'      => 120,
				'width'       => 90,
				'flex-height' => true,
				'flex-width'  => true,
			)
		);

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'script',
				'style',
			)
		);

		/*
		 * Posts Format.
		 *
		 * https://wordpress.org/support/article/post-formats/
		 */
		add_theme_support( 'post-formats', array(
		    'video',
		    'audio',
		    'gallery',
		    'quote',
		    'image'
		) );

		// Woocommerce Support
		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-zoom' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );

		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on NewsFort, use a find and replace
		 * to change 'newsfort' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'newsfort', get_template_directory() . '/languages' );

        /*
         * Enable support Gutenberg and Block styles.
         *
         */
        add_theme_support( 'align-wide' );
        add_theme_support( 'responsive-embeds' );
        add_theme_support( 'wp-block-styles' );

	}

endif;

add_action( 'after_setup_theme', 'newsfort_after_theme_support' );

/**
 * Register and Enqueue Styles.
 */
function newsfort_register_styles() {

	$theme_version = wp_get_theme()->get( 'Version' );
	$fonts_url = newsfort_fonts_url();
    if( $fonts_url ){
    	
    	require_once get_theme_file_path( 'assets/lib/custom/css/wptt-webfont-loader.php' );
        wp_enqueue_style(
			'newsfort-google-fonts',
			wptt_get_webfont_url( $fonts_url ),
			array(),
			$theme_version
		);
    }

    wp_enqueue_style( 'magnific-popup', get_template_directory_uri() . '/assets/lib/magnific-popup/magnific-popup.css' );
    wp_enqueue_style( 'slick', get_template_directory_uri() . '/assets/lib/slick/css/slick.min.css');
	wp_enqueue_style( 'newsfort-style', get_stylesheet_uri(), array(), $theme_version );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}	

	wp_enqueue_script( 'imagesloaded' );
    wp_enqueue_script( 'masonry' );
    wp_enqueue_script( 'magnific-popup', get_template_directory_uri() . '/assets/lib/magnific-popup/jquery.magnific-popup.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'slick', get_template_directory_uri() . '/assets/lib/slick/js/slick.min.js', array('jquery'), '', 1);
	wp_enqueue_script( 'theiaStickySidebar', get_template_directory_uri() . '/assets/lib/theiaStickySidebar/theia-sticky-sidebar.js', array('jquery'), '', 1);
	wp_enqueue_script( 'newsfort-ajax', get_template_directory_uri() . '/assets/lib/custom/js/ajax.js', array('jquery'), '', true );
	wp_enqueue_script( 'newsfort-custom', get_template_directory_uri() . '/assets/lib/custom/js/custom.js', array('jquery'), '', 1);
	wp_enqueue_script( 'newsfort-pagination', get_template_directory_uri() . '/assets/lib/custom/js/pagination.js', array('jquery'), '', 1 );
	
    $ajax_nonce = wp_create_nonce('newsfort_ajax_nonce');

    wp_localize_script( 
        'newsfort-ajax', 
        'newsfort_ajax',
        array(
            'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
            'ajax_nonce' => $ajax_nonce,

         )
    );

    // Global Query
    if( is_front_page() ){

    	$posts_per_page = absint( get_option('posts_per_page') );
        $c_paged = ( get_query_var( 'page' ) ) ? absint( get_query_var( 'page' ) ) : 1;
        $posts_args = array(
            'posts_per_page'        => $posts_per_page,
            'paged'                 => $c_paged,
        );
        $posts_qry = new WP_Query( $posts_args );
        $max = $posts_qry->max_num_pages;

    }else{
        global $wp_query;
        $max = $wp_query->max_num_pages;
        $c_paged = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
    }

    $newsfort_default = newsfort_get_default_theme_options();
    $newsfort_pagination_layout = get_theme_mod( 'newsfort_pagination_layout',$newsfort_default['newsfort_pagination_layout'] );
    $wide_layout = get_theme_mod( 'ed_ticker_slider_wide_layout',$newsfort_default['ed_ticker_slider_wide_layout'] );

    // Pagination Data
    wp_localize_script( 
	    'newsfort-pagination', 
	    'newsfort_pagination',
	    array(
	        'paged'  => absint( $c_paged ),
	        'maxpage'   => absint( $max ),
	        'nextLink'   => next_posts( $max, false ),
	        'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
	        'loadmore'   => esc_html__( 'Load More Posts', 'newsfort' ),
	        'nomore'     => esc_html__( 'No More Posts', 'newsfort' ),
	        'loading'    => esc_html__( 'Loading...', 'newsfort' ),
	        'pagination_layout'   => esc_html( $newsfort_pagination_layout ),
	        'ajax_nonce' => $ajax_nonce,
	     )
	);

    global $post;
    $single_post = 0;
    $newsfort_ed_post_reaction = '';
    if( isset( $post->ID ) && isset( $post->post_type ) && $post->post_type == 'post' ){

    	$newsfort_ed_post_reaction = esc_html( get_post_meta( $post->ID, 'newsfort_ed_post_reaction', true ) );
    	$single_post = 1;

    }
	wp_localize_script(
	    'newsfort-custom', 
	    'newsfort_custom',
	    array(
	    	'single_post'						=> absint( $single_post ),
	        'newsfort_ed_post_reaction'  		=> esc_html( $newsfort_ed_post_reaction ),
	        'next_svg'   => newsfort_the_theme_svg('chevron-right',true),
            'prev_svg' => newsfort_the_theme_svg('chevron-left',true),
            'play' => newsfort_the_theme_svg( 'play', $return = true ),
            'pause' => newsfort_the_theme_svg( 'pause', $return = true ),
            'mute' => newsfort_the_theme_svg( 'mute', $return = true ),
            'unmute' => newsfort_the_theme_svg( 'unmute', $return = true ),
            'play_text' => esc_html__('Play','newsfort'),
            'pause_text' => esc_html__('Pause','newsfort'),
            'mute_text' => esc_html__('Mute','newsfort'),
            'unmute_text' => esc_html__('Unmute','newsfort'),
            'wide_layout'	=> absint( $wide_layout ),
	     )
	);

}

add_action( 'wp_enqueue_scripts', 'newsfort_register_styles' );

/**
 * Admin enqueue script
 */
function newsfort_admin_scripts($hook){

	$current_screen = get_current_screen();
	wp_enqueue_style('newsfort-admin', get_template_directory_uri() . '/assets/lib/custom/css/admin.css');
    if( $current_screen->id != "widgets" ) {

		wp_enqueue_media();
		wp_enqueue_style( 'wp-color-picker' );
	    
	    wp_enqueue_script('newsfort-admin', get_template_directory_uri() . '/assets/lib/custom/js/admin.js', array('jquery','wp-color-picker'), '', 1);

	    $ajax_nonce = wp_create_nonce('newsfort_ajax_nonce');
				
		wp_localize_script( 
	        'newsfort-admin', 
	        'newsfort_admin',
	        array(
	            'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
	            'ajax_nonce' => $ajax_nonce,
	            'upload_image'   =>  esc_html__('Choose Image','newsfort'),
	            'use_image'   =>  esc_html__('Select','newsfort'),
	            'active' => esc_html__('Active','newsfort'),
		        'deactivate' => esc_html__('Deactivate','newsfort'),
	         )
	    );

	}

    if( $current_screen->id === "widgets" ) {

        // Enqueue Script Only On Widget Page.
        wp_enqueue_media();
    	wp_enqueue_script('newsfort-widget', get_template_directory_uri() . '/assets/lib/custom/js/widget.js', array('jquery'), '', 1);
	}
    
}

add_action('admin_enqueue_scripts', 'newsfort_admin_scripts');


if( !function_exists( 'newsfort_js_no_js_class' ) ) :

	// js no-js class toggle
	function newsfort_js_no_js_class() { ?>

		<script>document.documentElement.className = document.documentElement.className.replace( 'no-js', 'js' );</script>
	
	<?php
	}
	
endif;

add_action( 'wp_head', 'newsfort_js_no_js_class' );

/**
 * Register navigation menus uses wp_nav_menu in five places.
 */
function newsfort_menus() {

	$locations = array(
		'newsfort-primary-menu'  => __( 'Primary Menu', 'newsfort' ),
		'newsfort-top-menu'  => __( 'Top Nav Menu', 'newsfort' ),
		'newsfort-footer-menu'  => __( 'Footer Menu', 'newsfort' ),
		'newsfort-social-menu'  => __( 'Social Menu', 'newsfort' ),
	);

	register_nav_menus( $locations );
}

add_action( 'init', 'newsfort_menus' );



add_filter('wp_nav_menu_items', 'newsfort_add_admin_link', 1, 2);
function newsfort_add_admin_link($items, $args){
    if( $args->theme_location == 'newsfort-primary-menu' ){
        $item = '<li class="brand-home"><a title="'.esc_html__('Home','newsfort').'" href="'. esc_url( home_url() ) .'">' . "<span>".newsfort_the_theme_svg('homemark', true)."</span>" . '</a></li>';
        $items = $item . $items;
    }
    return $items;
}

if( class_exists('Demo_Import_Kit_Class') ):

	add_filter('themeinwp_enable_demo_import_compatiblity','newsfort_demo_import_filter_apply');

	if( !function_exists('newsfort_demo_import_filter_apply') ):

		function newsfort_demo_import_filter_apply(){

			return true;

		}

endif;

endif;

/**
 * Recommended Plugins
 */
require get_template_directory() . '/assets/lib/tgmpa/recommended-plugins.php';
require get_template_directory() . '/classes/class-svg-icons.php';
require get_template_directory() . '/inc/customizer/customizer.php';
require get_template_directory() . '/classes/class-walker-menu.php';
require get_template_directory() . '/inc/mega-menu/megamenu-custom-fields.php';
require get_template_directory() . '/inc/mega-menu/walkernav.php';
require get_template_directory() . '/inc/custom-header.php';
require get_template_directory() . '/inc/single-related-posts.php';
require get_template_directory() . '/inc/custom-functions.php';
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/classes/body-classes.php';
require get_template_directory() . '/inc/widgets/widgets.php';
require get_template_directory() . '/inc/metabox.php';
require get_template_directory() . '/inc/term-meta.php';
require get_template_directory() . '/inc/pagination.php';
require get_template_directory() . '/assets/lib/breadcrumbs/breadcrumbs.php';
require get_template_directory() . '/template-parts/components/archive-content.php';
require get_template_directory() . '/template-parts/components/main-banner.php';
require get_template_directory() . '/template-parts/components/tiles-block.php';
require get_template_directory() . '/template-parts/components/lead-block.php';
require get_template_directory() . '/template-parts/components/info-block.php';
require get_template_directory() . '/template-parts/components/banner-block-2.php';
require get_template_directory() . '/template-parts/components/banner-block-3.php';
require get_template_directory() . '/template-parts/components/banner-block-4.php';
require get_template_directory() . '/template-parts/components/advertise-block.php';
require get_template_directory() . '/template-parts/components/carousel-block.php';
require get_template_directory() . '/template-parts/components/masonry-block.php';
require get_template_directory() . '/template-parts/components/slider-block.php';
require get_template_directory() . '/template-parts/components/post-list-block.php';
require get_template_directory() . '/template-parts/components/latest-posts-block.php';
require get_template_directory() . '/template-parts/components/home-widget-area.php';
require get_template_directory() . '/assets/lib/custom/css/style.php';
require get_template_directory() . '/classes/admin-notice.php';
require get_template_directory() . '/classes/plugin-classes.php';
require get_template_directory() . '/classes/about.php';