<?php
/**
 * Custom Functions.
 *
 * @package NewsFort
 */

if( !function_exists( 'newsfort_fonts_url' ) ) :

    //Google Fonts URL
    function newsfort_fonts_url(){

        $fonts_url = '';
        $fonts = array();

        $newsfort_font = 'Roboto:ital,wght@0,100;0,300;0,400;0,500;0,700;0,900;1,100;1,300;1,400;1,500;1,700;1,900&display=swap';

        $newsfort_fonts = array();
        $newsfort_fonts[] = $newsfort_font;

        $newsfort_fonts_stylesheet = '//fonts.googleapis.com/css?family=';

        $i = 0;
        for ( $i = 0; $i < count( $newsfort_fonts ); $i++ ) {

            if ( 'off' !== sprintf( _x( 'on', '%s font: on or off', 'newsfort' ), $newsfort_fonts[$i] ) ) {
                $fonts[] = $newsfort_fonts[$i];
            }

        }

        if ( $fonts ) {
            $fonts_url = add_query_arg( array(
                'family' => urldecode( implode( '|', $fonts ) ),
            ), 'https://fonts.googleapis.com/css' );
        }

        return esc_url_raw($fonts_url);
    }

endif;

if( !function_exists( 'newsfort_sanitize_sidebar_option_meta' ) ) :

    // Sidebar Option Sanitize.
    function newsfort_sanitize_sidebar_option_meta( $input ){

        $metabox_options = array( 'global-sidebar','left-sidebar','right-sidebar','no-sidebar' );
        if( in_array( $input,$metabox_options ) ){

            return $input;

        }else{

            return '';

        }
    }

endif;

if( !function_exists( 'newsfort_page_lists' ) ) :

    // Page List.
    function newsfort_page_lists(){

        $page_lists = array();
        $page_lists[''] = esc_html__( '-- Select Page --','newsfort' );
        $pages = get_pages(
            array (
                'parent'  => 0, // replaces 'depth' => 1,
            )
        );
        foreach( $pages as $page ){

            $page_lists[$page->ID] = $page->post_title;

        }
        return $page_lists;
    }

endif;

if( !function_exists( 'newsfort_sanitize_post_layout_option_meta' ) ) :

    // Sidebar Option Sanitize.
    function newsfort_sanitize_post_layout_option_meta( $input ){

        $metabox_options = array( 'global-layout','layout-1','layout-2' );
        if( in_array( $input,$metabox_options ) ){

            return $input;

        }else{

            return '';

        }

    }

endif;

if( !function_exists( 'newsfort_sanitize_header_overlay_option_meta' ) ) :

    // Sidebar Option Sanitize.
    function newsfort_sanitize_header_overlay_option_meta( $input ){

        $metabox_options = array( 'global-layout','enable-overlay' );
        if( in_array( $input,$metabox_options ) ){

            return $input;

        }else{

            return '';

        }

    }

endif;

/**
 * NewsFort SVG Icon helper functions
 *
 * @package NewsFort
 * @since 1.0.0
 */
if ( ! function_exists( 'newsfort_the_theme_svg' ) ):
    /**
     * Output and Get Theme SVG.
     * Output and get the SVG markup for an icon in the NewsFort_SVG_Icons class.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function newsfort_the_theme_svg( $svg_name, $return = false ) {

        if( $return ){

            return newsfort_get_theme_svg( $svg_name ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in newsfort_get_theme_svg();.

        }else{

            echo newsfort_get_theme_svg( $svg_name ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in newsfort_get_theme_svg();.
            
        }
    }

endif;

if ( ! function_exists( 'newsfort_get_theme_svg' ) ):

    /**
     * Get information about the SVG icon.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function newsfort_get_theme_svg( $svg_name ) {

        // Make sure that only our allowed tags and attributes are included.
        $svg = wp_kses(
            NewsFort_SVG_Icons::get_svg( $svg_name ),
            array(
                'svg'     => array(
                    'class'       => true,
                    'xmlns'       => true,
                    'width'       => true,
                    'height'      => true,
                    'viewbox'     => true,
                    'aria-hidden' => true,
                    'role'        => true,
                    'focusable'   => true,
                ),
                'path'    => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'd'         => true,
                    'transform' => true,
                ),
                'polygon' => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'points'    => true,
                    'transform' => true,
                    'focusable' => true,
                ),
            )
        );
        if ( ! $svg ) {
            return false;
        }
        return $svg;

    }

endif;

if ( ! function_exists( 'newsfort_svg_escape' ) ):

    /**
     * Get information about the SVG icon.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function newsfort_svg_escape( $input ) {

        // Make sure that only our allowed tags and attributes are included.
        $svg = wp_kses(
            $input,
            array(
                'svg'     => array(
                    'class'       => true,
                    'xmlns'       => true,
                    'width'       => true,
                    'height'      => true,
                    'viewbox'     => true,
                    'aria-hidden' => true,
                    'role'        => true,
                    'focusable'   => true,
                ),
                'path'    => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'd'         => true,
                    'transform' => true,
                ),
                'polygon' => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'points'    => true,
                    'transform' => true,
                    'focusable' => true,
                ),
            )
        );

        if ( ! $svg ) {
            return false;
        }

        return $svg;

    }

endif;

if( !function_exists('newsfort_post_format_icon') ):

    // Post Format Icon.
    function newsfort_post_format_icon( $format ){

        if( $format == 'video' ){
            $icon = newsfort_get_theme_svg( 'video' );
        }elseif( $format == 'audio' ){
            $icon = newsfort_get_theme_svg( 'audio' );
        }elseif( $format == 'gallery' ){
            $icon = newsfort_get_theme_svg( 'gallery' );
        }elseif( $format == 'quote' ){
            $icon = newsfort_get_theme_svg( 'quote' );
        }elseif( $format == 'image' ){
            $icon = newsfort_get_theme_svg( 'image' );
        }else{
            $icon = '';
        }

        return $icon;
    }

endif;

if( !function_exists( 'newsfort_social_menu_icon' ) ) :

    function newsfort_social_menu_icon( $item_output, $item, $depth, $args ) {

        // Add Icon
        if ( isset( $args->theme_location ) && 'newsfort-social-menu' === $args->theme_location ) {

            $svg = NewsFort_SVG_Icons::get_theme_svg_name( $item->url );

            if ( empty( $svg ) ) {
                $svg = newsfort_the_theme_svg( 'link',$return = true );
            }

            $item_output = str_replace( $args->link_after, '</span>' . $svg, $item_output );
        }

        return $item_output;
    }
    
endif;

add_filter( 'walker_nav_menu_start_el', 'newsfort_social_menu_icon', 10, 4 );

if ( ! function_exists( 'newsfort_sub_menu_toggle_button' ) ) :

    function newsfort_sub_menu_toggle_button( $args, $item, $depth ) {

        // Add sub menu toggles to the main menu with toggles
        if ( $args->theme_location == 'newsfort-primary-menu' && isset( $args->show_toggles ) ) {
            // Wrap the menu item link contents in a div, used for positioning
            $args->before = '<div class="submenu-wrapper">';
            $args->after  = '';
            // Add a toggle to items with children
            if ( in_array( 'menu-item-has-children', $item->classes ) ) {
                $toggle_target_string = '.menu-item.menu-item-' . $item->ID . ' > .sub-menu';
                // Add the sub menu toggle
                $args->after .= '<button type="button" class="theme-aria-button submenu-toggle" data-toggle-target="' . $toggle_target_string . '" data-toggle-type="slidetoggle" data-toggle-duration="250" aria-expanded="false"><span class="btn__content" tabindex="-1"><span class="screen-reader-text">' . __( 'Show sub menu', 'newsfort' ) . '</span>' . newsfort_get_theme_svg( 'chevron-down' ) . '</span></button>';
            }
            // Close the wrapper
            $args->after .= '</div><!-- .submenu-wrapper -->';
            // Add sub menu icons to the main menu without toggles (the fallback menu)
        } elseif ( $args->theme_location == 'newsfort-primary-menu' ) {
            if ( in_array( 'menu-item-has-children', $item->classes ) ) {
                $args->before = '<div class="link-icon-wrapper">';
                $args->after  = newsfort_get_theme_svg( 'chevron-down' ) . '</div>';
            } else {
                $args->before = '';
                $args->after  = '';
            }
        }
        return $args;

    }

    add_filter( 'nav_menu_item_args', 'newsfort_sub_menu_toggle_button', 10, 3 );

endif;

if( !function_exists( 'newsfort_post_category_list' ) ) :

    // Post Category List.
    function newsfort_post_category_list( $select_cat = true ){

        $post_cat_lists = get_categories(
            array(
                'hide_empty' => '0',
                'exclude' => '1',
            )
        );

        $post_cat_cat_array = array();
        if( $select_cat ){

            $post_cat_cat_array[''] = esc_html__( '-- Select Category --','newsfort' );

        }

        foreach ( $post_cat_lists as $post_cat_list ) {

            $post_cat_cat_array[$post_cat_list->slug] = $post_cat_list->name;

        }

        return $post_cat_cat_array;
    }

endif;

if( !function_exists('newsfort_sanitize_meta_pagination') ):

    /** Sanitize Enable Disable Checkbox **/
    function newsfort_sanitize_meta_pagination( $input ) {

        $valid_keys = array('global-layout','no-navigation','norma-navigation','ajax-next-post-load');
        if ( in_array( $input , $valid_keys ) ) {
            return $input;
        }
        return '';

    }

endif;

if( !function_exists('newsfort_disable_post_views') ):

    /** Disable Post Views **/
    function newsfort_disable_post_views() {

        add_filter('booster_extension_filter_views_ed', 'newsfort_disable_views_ed');

    }

endif;

if( !function_exists('newsfort_disable_views_ed') ):

    /** Disable Reaction **/
    function newsfort_disable_views_ed() {

        return false;

    }

endif;

if( !function_exists('newsfort_disable_post_read_time') ):

    /** Disable Read Time **/
    function newsfort_disable_post_read_time() {

        add_filter('booster_extension_filter_readtime_ed', 'newsfort_disable_read_time');

    }

endif;

if( !function_exists('newsfort_disable_read_time') ):

    /** Disable Reaction **/
    function newsfort_disable_read_time() {

        return false;

    }

endif;

if( !function_exists('newsfort_disable_post_like_dislike') ):

    /** Disable Like Dislike **/
    function newsfort_disable_post_like_dislike() {

        add_filter('booster_extension_filter_like_ed', 'newsfort_disable_like_ed');

    }

endif;

if( !function_exists('newsfort_disable_like_ed') ):

    /** Disable Reaction **/
    function newsfort_disable_like_ed() {

        return false;

    }

endif;

if( !function_exists('newsfort_disable_post_author_box') ):

    /** Disable Author Box **/
    function newsfort_disable_post_author_box() {

        add_filter('booster_extension_filter_ab_ed','newsfort_disable_ab_ed');

    }

endif;

if( !function_exists('newsfort_disable_ab_ed') ):

    /** Disable Reaction **/
    function newsfort_disable_ab_ed() {

        return false;

    }

endif;

add_filter('booster_extension_filter_ss_ed', 'newsfort_disable_social_share');

if( !function_exists('newsfort_disable_social_share') ):

    /** Disable Reaction **/
    function newsfort_disable_social_share() {

        return false;

    }

endif;

if( !function_exists('newsfort_disable_post_reaction') ):

    /** Disable Reaction **/
    function newsfort_disable_post_reaction() {

        add_filter('booster_extension_filter_reaction_ed', 'newsfort_disable_reaction_cb');

    }

endif;

if( !function_exists('newsfort_disable_reaction_cb') ):

    /** Disable Reaction **/
    function newsfort_disable_reaction_cb() {

        return false;

    }

endif;

if( !function_exists( 'newsfort_header_ad' ) ):

    function newsfort_header_ad(){

        $newsfort_default = newsfort_get_default_theme_options();
        $ed_header_ad = get_theme_mod( 'ed_header_ad',$newsfort_default['ed_header_ad'] );
        $header_ad_image = get_theme_mod( 'header_ad_image' );
        $ed_header_link = get_theme_mod( 'ed_header_link' );

        if( $ed_header_ad ){

            ?>
            <div class="header-extras header-extras-top">
                <div class="header-ava-area">
                    <div class="wrapper">
                        <?php if( $header_ad_image ){ ?>
                            <a target="_blank" href="<?php echo esc_url( $ed_header_link ); ?>">
                                <img src="<?php echo esc_url( $header_ad_image ); ?>" title="<?php esc_attr_e('Header AD Image','newsfort'); ?>" alt="<?php esc_attr_e('Header AD Image','newsfort'); ?>" />
                            </a>
                        <?php } ?>
                    </div>
                </div>
            </div>
            <?php

        }
    }

endif;

if( !function_exists('newsfort_post_floating_nav') ):

    function newsfort_post_floating_nav(){

        $newsfort_default = newsfort_get_default_theme_options();
        $ed_floating_next_previous_nav = get_theme_mod( 'ed_floating_next_previous_nav',$newsfort_default['ed_floating_next_previous_nav'] );

        if( 'post' === get_post_type() && $ed_floating_next_previous_nav ){

            $next_post = get_next_post();
            $prev_post = get_previous_post();

            if( isset( $prev_post->ID ) ){

                $prev_link = get_permalink( $prev_post->ID );?>

                <div class="floating-post-navigation floating-navigation-prev">
                    <?php if( get_the_post_thumbnail( $prev_post->ID,'medium' ) ){ ?>
                            <?php echo wp_kses_post( get_the_post_thumbnail( $prev_post->ID,'medium' ) ); ?>
                    <?php } ?>
                    <a href="<?php echo esc_url( $prev_link ); ?>">
                        <span class="floating-navigation-label"><?php echo esc_html__('Previous post', 'newsfort'); ?></span>
                        <span class="floating-navigation-title"><?php echo esc_html( get_the_title( $prev_post->ID ) ); ?></span>
                    </a>
                </div>

            <?php }

            if( isset( $next_post->ID ) ){

                $next_link = get_permalink( $next_post->ID );?>

                <div class="floating-post-navigation floating-navigation-next">
                    <?php if( get_the_post_thumbnail( $next_post->ID,'medium' ) ){ ?>
                        <?php echo wp_kses_post( get_the_post_thumbnail( $next_post->ID,'medium' ) ); ?>
                    <?php } ?>
                    <a href="<?php echo esc_url( $next_link ); ?>">
                        <span class="floating-navigation-label"><?php echo esc_html__('Next post', 'newsfort'); ?></span>
                        <span class="floating-navigation-title"><?php echo esc_html( get_the_title( $next_post->ID ) ); ?></span>
                    </a>
                </div>

            <?php
            }

        }

    }

endif;

add_action( 'newsfort_navigation_action','newsfort_post_floating_nav',10 );

if( !function_exists('newsfort_single_post_navigation') ):

    function newsfort_single_post_navigation(){

        $newsfort_default = newsfort_get_default_theme_options();
        $twp_navigation_type = esc_attr( get_post_meta( get_the_ID(), 'twp_disable_ajax_load_next_post', true ) );
        $newsfort_header_trending_page = get_theme_mod( 'newsfort_header_trending_page' );
        $newsfort_header_popular_page = get_theme_mod( 'newsfort_header_popular_page' );
        $newsfort_archive_layout = esc_attr( get_theme_mod( 'newsfort_archive_layout', $newsfort_default['newsfort_archive_layout'] ) );
        $current_id = '';
        $article_wrap_class = '';
        global $post;
        $current_id = $post->ID;
        if( $twp_navigation_type == '' || $twp_navigation_type == 'global-layout' ){
            $twp_navigation_type = get_theme_mod('twp_navigation_type', $newsfort_default['twp_navigation_type']);
        }

        if( $newsfort_header_trending_page != $current_id && $newsfort_header_popular_page != $current_id ){

            if( $twp_navigation_type != 'no-navigation' && 'post' === get_post_type() ){

                if( $twp_navigation_type == 'norma-navigation' ){ ?>

                    <div class="navigation-wrapper">
                        <?php
                        // Previous/next post navigation.
                        the_post_navigation(array(
                            'prev_text' => '<span class="arrow" aria-hidden="true">' . newsfort_the_theme_svg('arrow-left',$return = true ) . '</span><span class="screen-reader-text">' . __('Previous post:', 'newsfort') . '</span><span class="post-title">%title</span>',
                            'next_text' => '<span class="arrow" aria-hidden="true">' . newsfort_the_theme_svg('arrow-right',$return = true ) . '</span><span class="screen-reader-text">' . __('Next post:', 'newsfort') . '</span><span class="post-title">%title</span>',
                        )); ?>
                    </div>
                    <?php

                }else{

                    $next_post = get_next_post();
                    if( isset( $next_post->ID ) ){

                        $next_post_id = $next_post->ID;
                        echo '<div loop-count="1" next-post="' . absint( $next_post_id ) . '" class="twp-single-infinity"></div>';

                    }
                }

            }

        }

    }

endif;

add_action( 'newsfort_navigation_action','newsfort_single_post_navigation',30 );


if( !function_exists('newsfort_header_banner') ):

    function newsfort_header_banner(){

        global $post;

        if( have_posts() ):

            while (have_posts()) :
                the_post();

                global $post;
                
            endwhile;

        endif;
        
        $newsfort_post_layout = '';
        $newsfort_default = newsfort_get_default_theme_options();

        if( is_singular() ){

            $newsfort_post_layout = esc_html( get_post_meta( $post->ID, 'newsfort_post_layout', true ) );
            if( $newsfort_post_layout == '' || $newsfort_post_layout == 'global-layout' ){
                
                $newsfort_post_layout = get_theme_mod( 'newsfort_single_post_layout',$newsfort_default['newsfort_archive_layout'] );
            }

        }

        if( isset( $post->ID ) ){

            $newsfort_page_layout = esc_html( get_post_meta( $post->ID, 'newsfort_page_layout', true ) );

        }

        if( $newsfort_post_layout == 'layout-2' && is_singular('post') ) {

            if ( have_posts() ) :

                while ( have_posts() ) :
                    the_post();

                    $featured_image = wp_get_attachment_image_src( get_post_thumbnail_id(),'full' );
                    $newsfort_ed_feature_image = esc_html( get_post_meta( get_the_ID(), 'newsfort_ed_feature_image', true ) );
                    ?>

                    <div class="single-featured-banner  <?php if( empty( $newsfort_ed_feature_image ) && isset( $featured_image[0] ) && $featured_image[0] ){ echo 'banner-has-image'; } ?>">

                        <div class="featured-banner-content">
                            <div class="wrapper">
                                <?php
                                if ( !is_404() && !is_home() && !is_front_page() ) {
                                    newsfort_breadcrumb();
                                } ?>

                                <div class="column-row">
                                    <div class="column column-12">
                                        <header class="entry-header entry-header-1">

                                            <div class="entry-meta">
                                                <?php
                                                newsfort_entry_footer($cats = true, $tags = false, $edits = false, $text = false, $icon = false);
                                                ?>
                                            </div>

                                            <h1 class="entry-title">
                                                <?php the_title(); ?>
                                            </h1>
                                        </header>
                                        <div class="entry-meta">
                                            <?php
                                            newsfort_posted_by();
                                            newsfort_posted_on();
                                            ?>
                                        </div>
                                    </div>
                                </div>
                                
                            </div>
                        </div>

                        <?php if( empty( $newsfort_ed_feature_image ) && isset( $featured_image[0] ) && $featured_image[0] ){ ?>
                            <div class="featured-banner-media">
                                <div class="data-bg data-bg-fixed data-bg-banner" data-background="<?php echo esc_url( $featured_image[0] ); ?>"></div>
                            </div>
                        <?php } ?>

                    </div>

                <?php
                endwhile;

                wp_reset_postdata();

            endif;
               
        }

        if( is_singular('page') && $newsfort_page_layout == 'layout-2' ) {

            if ( have_posts() ) :

                while ( have_posts() ) :

                    the_post();

                    $featured_image = wp_get_attachment_image_src( get_post_thumbnail_id(),'full' );
                    
                    $newsfort_ed_feature_image = esc_html( get_post_meta( get_the_ID(), 'newsfort_ed_feature_image', true ) );
                    ?>

                    <div class="single-featured-banner  <?php if( empty( $newsfort_ed_feature_image ) && isset( $featured_image[0] ) && $featured_image[0] ){ echo 'banner-has-image'; } ?>">

                        <div class="featured-banner-content">
                            <div class="wrapper">
                                <?php
                                if ( !is_404() && !is_home() && !is_front_page() ) {
                                    newsfort_breadcrumb();
                                } ?>

                                <div class="column-row">
                                    <div class="column column-12">
                                        <header class="entry-header entry-header-1">

                                            <h1 class="entry-title">
                                                <?php the_title(); ?>
                                            </h1>
                                        </header>
                                    </div>
                                </div>
                                
                            </div>
                        </div>

                        <?php if( empty( $newsfort_ed_feature_image ) && isset( $featured_image[0] ) && $featured_image[0] ){ ?>
                            <div class="featured-banner-media">
                                <div class="data-bg data-bg-fixed data-bg-banner" data-background="<?php echo esc_url( $featured_image[0] ); ?>"></div>
                            </div>
                        <?php } ?>

                    </div>

                <?php
                endwhile;

                wp_reset_postdata();

            endif;
               
        }

    }

endif;

if ( ! function_exists( 'newsfort_header_toggle_search' ) ):

    /**
     * Header Search
     **/
    function newsfort_header_toggle_search() {

        $newsfort_default = newsfort_get_default_theme_options();
        $ed_header_search = get_theme_mod('ed_header_search', $newsfort_default['ed_header_search']);
        $ed_header_search_top_category = get_theme_mod( 'ed_header_search_top_category', $newsfort_default['ed_header_search_top_category'] );
        $ed_header_search_recent_posts = absint( get_theme_mod( 'ed_header_search_recent_posts',$newsfort_default['ed_header_search_recent_posts'] ) );
        if( $ed_header_search ){ ?>

            <div class="header-searchbar">
                <div class="header-searchbar-inner">
                    <div class="wrapper">
                        <div class="header-searchbar-panel">
                            <div class="header-searchbar-area">

                                <a class="skip-link-search-top" href="javascript:void(0)"></a>

                                <?php get_search_form(); ?>

                            </div>

                            <?php if( $ed_header_search_recent_posts || $ed_header_search_top_category ){ ?>

                                <div class="search-content-area">

                                    <?php if( $ed_header_search_recent_posts ){ ?>

                                        <div class="search-recent-posts">
                                            <?php newsfort_recent_posts_search(); ?>
                                        </div>

                                    <?php } ?>

                                    <?php if( $ed_header_search_top_category ){ ?>

                                        <div class="search-popular-categories">
                                            <?php newsfort_header_search_top_cat_content(); ?>
                                        </div>

                                    <?php } ?>

                                </div>

                            <?php } ?>

                            <button type="button" id="search-closer" class="close-popup">
                                <?php newsfort_the_theme_svg('cross'); ?>
                            </button>
                        </div>
                    </div>
                </div>
            </div>

        <?php
        }

    }

endif;

add_action( 'newsfort_before_footer_content_action','newsfort_header_toggle_search',10 );

if( !function_exists('newsfort_recent_posts_search') ):

    // Single Posts Related Posts.
    function newsfort_recent_posts_search(){

        $newsfort_default = newsfort_get_default_theme_options();
        $related_posts_query = new WP_Query( array('post_type' => 'post', 'posts_per_page' => 5,'post__not_in' => get_option("sticky_posts") ) );

        if( $related_posts_query->have_posts() ): ?>

            <div class="theme-block related-search-posts">

                <div class="theme-block-heading">
                    <?php
                    $recent_post_title_search = esc_html( get_theme_mod( 'recent_post_title_search',$newsfort_default['recent_post_title_search'] ) );

                    if( $recent_post_title_search ){ ?>
                        <h2 class="theme-block-title">

                            <?php echo esc_html( $recent_post_title_search ); ?>

                        </h2>
                    <?php } ?>
                </div>

                <div class="theme-list-group recent-list-group">

                    <?php
                    while( $related_posts_query->have_posts() ):
                        $related_posts_query->the_post();

                        $featured_image = wp_get_attachment_image_src( get_post_thumbnail_id(),'medium' ); ?>

                        <article id="post-<?php the_ID(); ?>" <?php post_class('theme-list-article'); ?>>
                            <header class="entry-header">
                                <h3 class="entry-title">
                                    <a href="<?php the_permalink(); ?>" rel="bookmark">
                                        <?php the_title(); ?>
                                    </a>
                                </h3>
                            </header>
                        </article>

                    <?php 
                    endwhile; ?>

                </div>

            </div>

            <?php
            wp_reset_postdata();

        endif;

    }

endif;

if( !function_exists('newsfort_header_search_top_cat_content') ):

    function newsfort_header_search_top_cat_content(){

        $top_category = 4;

        $post_cat_lists = get_categories(
            array(
                'hide_empty' => '0',
                'exclude' => '1',
            )
        );

        $slug_counts = array();

        foreach( $post_cat_lists as $post_cat_list ){

            if( $post_cat_list->count >= 1 ){

                $slug_counts[] = array( 
                    'count'         => $post_cat_list->count,
                    'slug'          => $post_cat_list->slug,
                    'name'          => $post_cat_list->name,
                    'cat_ID'        => $post_cat_list->cat_ID,
                    'description'   => $post_cat_list->category_description, 
                );

            }

        }

        if( $slug_counts ){?>

            <div class="theme-block popular-search-categories">
                
                <div class="theme-block-heading">
                    <?php
                    $newsfort_default = newsfort_get_default_theme_options();
                    $top_category_title_search = esc_html( get_theme_mod( 'top_category_title_search',$newsfort_default['top_category_title_search'] ) );

                    if( $top_category_title_search ){ ?>
                        <h2 class="theme-block-title">

                            <?php echo esc_html( $top_category_title_search ); ?>

                        </h2>
                    <?php } ?>
                </div>

                <?php
                arsort( $slug_counts ); ?>

                <div class="theme-list-group categories-list-group">
                    <div class="column-row">

                        <?php
                        $i = 1;
                        foreach( $slug_counts as $key => $slug_count ){

                            if( $i > $top_category){ break; }
                            
                            $cat_link           = get_category_link( $slug_count['cat_ID'] );
                            $cat_name           = $slug_count['name'];
                            $twp_term_image = get_term_meta( $slug_count['cat_ID'], 'twp-term-featured-image', true ); ?>

                            <div class="column column-3 column-column-sm-12">
                                
                                <div class="post-thumb-categories">
                                    <div class="data-bg data-bg-medium thumb-overlay img-hover-slide"
                                         data-background="<?php echo esc_url($twp_term_image); ?>">
                                        <a class="img-link" href="<?php echo esc_url($cat_link); ?>"
                                           tabindex="0"></a>
                                        <div class="article-content article-content-overlay">
                                            <?php
                                            if ($cat_name) { ?>

                                                <h3 class="category-title">
                                                    <span><?php echo esc_html($cat_name); ?></span>
                                                </h3>
                                            <?php } ?>
                                        </div>
                                    </div>
                                </div>

                            </div>

                            <?php
                            $i++;

                        } ?>

                    </div>
                </div>

            </div>
        <?php
        }

    }

endif;

if( !function_exists('newsfort_top_nav') ):

    function newsfort_top_nav(){

        $newsfort_default = newsfort_get_default_theme_options();
        $ed_top_header = get_theme_mod( 'ed_top_header', $newsfort_default['ed_top_header'] );
        $ed_top_header_date = get_theme_mod( 'ed_top_header_date', $newsfort_default['ed_top_header_date'] );

        if( $ed_top_header && ( has_nav_menu('newsfort-top-menu') || has_nav_menu('newsfort-social-menu') || $ed_top_header_date ) ){ ?>

            <div id="site-topbar" class="site-topbar-layout">
                
                <?php newsfort_top_nav_render(); ?>

            </div>

        <?php
        }

    }

endif;

if( !function_exists('newsfort_top_nav_render') ):

    function newsfort_top_nav_render( $render = true ){

        ob_start();

        $newsfort_default = newsfort_get_default_theme_options();
        $ed_top_header = get_theme_mod( 'ed_top_header', $newsfort_default['ed_top_header'] );
        $ed_top_header_date = get_theme_mod( 'ed_top_header_date', $newsfort_default['ed_top_header_date'] );

        if( $ed_top_header && ( has_nav_menu('newsfort-top-menu') || has_nav_menu('newsfort-social-menu') || $ed_top_header_date ) ){ ?>

            <div class="wrapper">
                <div class="column-row">

                    <div class="column column-8 column-sm-12 mb-sm-15">
                        <div class="topbar-controls">

                            <?php
                            if( $ed_top_header_date ){ ?>

                                <div class="topbar-control">
                                    <div class="top-nav-date"><?php echo wp_kses_post( date( get_option('date_format') ) ); ?></div>
                                </div>

                            <?php }

                            if( has_nav_menu('newsfort-top-menu') ){ ?>

                                <div class="topbar-control">
                                    <div class="top-nav-menu">

                                        <?php
                                            wp_nav_menu(
                                                array(
                                                    'theme_location' => 'newsfort-top-menu',
                                                    'container' => 'div',
                                                    'container_class' => 'newsfort-top-menu',
                                                    'depth' => 1,
                                                )
                                            );
                                        ?>

                                    </div>
                                </div>

                            <?php } ?>

                        </div>
                    </div>


                    <div class="column column-4 column-sm-12 mb-sm-15">
                        <?php
                        if( has_nav_menu('newsfort-social-menu') ){ ?>

                            <div class="topbar-social-navigation">

                                <?php
                                wp_nav_menu(

                                    array(
                                        'theme_location' => 'newsfort-social-menu',
                                        'link_before' => '<span class="screen-reader-text">',
                                        'link_after' => '</span>',
                                        'container' => 'div',
                                        'container_class' => 'newsfort-social-menu',
                                        'depth' => 1,
                                    )

                                ); ?>

                            </div>

                        <?php } ?>
                    </div>

                </div>
            </div>

        <?php
        }

        $html = ob_get_contents();
        ob_get_clean();

        if( $render ){

            echo $html;

        }else{

            return $html;

        }

    }

endif;

if( !function_exists('newsfort_content_offcanvas') ):

    // Offcanvas Contents
    function newsfort_content_offcanvas(){

    $responsive_content = false;
    $newsfort_default = newsfort_get_default_theme_options();
    $ed_top_header = get_theme_mod( 'ed_top_header', $newsfort_default['ed_top_header'] );
    $ed_top_header_date = get_theme_mod( 'ed_top_header_date', $newsfort_default['ed_top_header_date'] );

    if( $ed_top_header && ( has_nav_menu('newsfort-top-menu') || has_nav_menu('newsfort-social-menu') || $ed_top_header_date ) ){

        $responsive_content = true;

    }
     ?>

        <div id="offcanvas-menu">
            <div class="offcanvas-wraper">

                <div class="close-offcanvas-menu">

                    <a class="skip-link-off-canvas" href="javascript:void(0)"></a>

                    <div class="offcanvas-close">

                        <?php if( $responsive_content ){ ?>
                            <div class="responsive-content-date"></div>
                        <?php } ?>

                        <button type="button" class="button-offcanvas-close">

                            <span class="offcanvas-close-label">
                                <?php echo esc_html__('Close', 'newsfort'); ?>
                            </span>

                            <span class="bars">
                                <span class="bar"></span>
                                <span class="bar"></span>
                                <span class="bar"></span>
                            </span>

                        </button>

                    </div>
                </div>

                <div id="primary-nav-offcanvas" class="offcanvas-item offcanvas-main-navigation">
                    <nav class="primary-menu-wrapper">
                        <ul class="primary-menu theme-menu">

                            <?php
                            if( has_nav_menu('newsfort-primary-menu') ){

                                wp_nav_menu(
                                    array(
                                        'container' => '',
                                        'items_wrap' => '%3$s',
                                        'theme_location' => 'newsfort-primary-menu',
                                        'show_toggles' => true,
                                    )
                                );

                            }else{

                                wp_list_pages(
                                    array(
                                        'match_menu_classes' => true,
                                        'title_li' => false,
                                        'show_toggles' => true,
                                        'walker' => new NewsFort_Walker_Page(),
                                    )
                                );

                            } ?>

                        </ul>
                    </nav>
                </div>

                <?php if (has_nav_menu('newsfort-social-menu')) { ?>

                    <div id="social-nav-offcanvas" class="offcanvas-item offcanvas-social-navigation">

                        <?php
                        wp_nav_menu(
                                array(
                                'theme_location' => 'newsfort-social-menu',
                                'link_before' => '<span class="screen-reader-text">',
                                'link_after' => '</span>',
                                'container' => 'div',
                                'container_class' => 'newsfort-social-menu',
                                'depth' => 1,
                            )
                        ); ?>

                    </div>

                <?php }

                if( $responsive_content ){ ?>
                    <div class="responsive-content-menu">

                    </div>
                <?php } ?>

                <a class="skip-link-offcanvas screen-reader-text" href="javascript:void(0)"></a>
                
            </div>
        </div>

    <?php
    }

endif;

add_action( 'newsfort_before_footer_content_action','newsfort_content_offcanvas',30 );

if( !function_exists('newsfort_footer_affix_posts') ):

    // Footer Affix Posts
    function newsfort_footer_affix_posts(){

        $newsfort_default = newsfort_get_default_theme_options();
        $ed_affix_post = absint( get_theme_mod( 'ed_affix_post',$newsfort_default['ed_affix_post'] ) );
        $ed_affix_post_arrow = absint( get_theme_mod( 'ed_affix_post_arrow',$newsfort_default['ed_affix_post_arrow'] ) );
        $ed_affix_post_autoplay = absint( get_theme_mod( 'ed_affix_post_autoplay',$newsfort_default['ed_affix_post_autoplay'] ) );

        $footer_affix_posts = esc_html( get_theme_mod( 'footer_affix_posts' ) );
        if( $ed_affix_post ){

            $footer_affix_query = new WP_Query( array( 'post_type' => 'post', 'posts_per_page' => 8, 'category_name' => esc_html( $footer_affix_posts ) ) ); ?>

            <div class="drawer-handle">
                <button class="drawer-handle-open">
                    <?php newsfort_the_theme_svg('plus'); ?>
                </button>
            </div>

            <?php if( $footer_affix_query->have_posts() ){

                if ( $ed_affix_post_autoplay ) {
                    $autoplay = 'true';
                }else{
                    $autoplay = 'false';
                }
                if( $ed_affix_post_arrow ) {
                    $arrows = 'true';
                }else {
                    $arrows = 'false';
                }
                if( is_rtl() ) {
                    $rtl = 'true';
                }else{
                    $rtl = 'false';
                }
            ?>

                <div class="affix-panel-content">
                    <button class="affix-handle-close">
                        <?php newsfort_the_theme_svg('cross'); ?>
                    </button>
                    <div class="affix-panel-slider">
                        <div class="wrapper">
                            <div class="affix-carousel" data-slick='{"autoplay": <?php echo esc_attr( $autoplay ); ?>, "arrows": <?php echo esc_attr( $arrows ); ?>, "rtl": <?php echo esc_attr( $rtl ); ?>}'>

                                <?php
                                while( $footer_affix_query->have_posts() ){
                                    $footer_affix_query->the_post();
                                    $featured_image = wp_get_attachment_image_src( get_post_thumbnail_id(),'thumbnail' );
                                    $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>

                                    <div class="slide-item">
                                        <article class="news-article">
                                            <div class="column-row">

                                                <?php if( $featured_image ){ ?>
                                                    <div class="column column-4">
                                                        <div class="post-thumbnail">
                                                            <div class="img-hover-scale">
                                                                <a href="<?php the_permalink(); ?>" tabindex="0" >
                                                                    <img title="<?php the_title_attribute(); ?>" alt="<?php the_title_attribute(); ?>" src="<?php echo esc_url( $featured_image ); ?>">
                                                                </a>
                                                            </div>
                                                        </div>
                                                    </div>
                                                <?php } ?>

                                                <div class="column column-<?php if(  $featured_image ){ ?>8<?php }else{ ?>12<?php } ?>">
                                                    <h3 class="entry-title entry-title-xsmall">
                                                        <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a>
                                                    </h3>
                                                    <div class="entry-meta">
                                                        <?php newsfort_posted_on(); ?>
                                                    </div>
                                                </div>

                                            </div>
                                        </article>
                                    </div>

                                <?php } ?>

                            </div>
                        </div>
                    </div>
                </div>

            <?php
            wp_reset_postdata(); }
        }
    }

endif;

add_action( 'newsfort_before_footer_content_action','newsfort_footer_affix_posts',40 );

if( !function_exists('newsfort_content_trending_news_render') ):

    function newsfort_content_trending_news_render(){

        $newsfort_header_trending_cat = get_theme_mod('newsfort_header_trending_cat');
        $trending_news_query = new WP_Query(
            array(
                'post_type' => 'post',
                'posts_per_page' => 9,
                'post__not_in' => get_option("sticky_posts"),
                'category_name' => $newsfort_header_trending_cat,
            )
        );

        if( $trending_news_query->have_posts() ): ?>

            <div class="trending-news-main-wrap">
               <div class="wrapper">
                    <div class="column-row">

                        <a href="javascript:void(0)" class="newsfort-skip-link-start"></a>

                        <div class="column column-12">
                            <button type="button" id="trending-collapse">
                                <?php newsfort_the_theme_svg('cross'); ?>
                            </button>
                        </div>

                        <?php
                        $post_count = 1;
                        while( $trending_news_query->have_posts() ){
                            $trending_news_query->the_post();

                            $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'thumbnail');
                            $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>
                            <div class="column column-4 column-sm-6">

                                <article id="theme-post-<?php the_ID(); ?>" <?php post_class('news-article news-article-bg news-article-bg-2 mb-20'); ?>>
                                    <div class="column-row">

                                        <?php if( $featured_image ){ ?>

                                            <div class="column column-4">

                                                <div class="data-bg data-bg-small" data-background="<?php echo esc_url($featured_image); ?>">

                                                    <?php
                                                    $format = get_post_format(get_the_ID()) ?: 'standard';
                                                    $icon = newsfort_post_format_icon($format);
                                                    if (!empty($icon)) { ?>
                                                        <span class="top-right-icon"><?php echo newsfort_svg_escape($icon); ?></span>
                                                    <?php } ?>
                                                    <a class="img-link" href="<?php the_permalink(); ?>" tabindex="0"></a>

                                                    <div class="trend-item">
                                                        <span class="number"> <?php echo $post_count; ?></span>
                                                    </div>
                                        
                                                </div>


                                            </div>

                                        <?php } ?>

                                        <div class="column column-<?php if ($featured_image) { ?>8<?php } else { ?>12<?php } ?>">
                                            <div class="article-content article-content-1">

                                                <h3 class="entry-title entry-title-small">
                                                    <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a>
                                                </h3>

                                                <div class="entry-meta">
                                                    <?php newsfort_posted_on(); ?>
                                                    <?php newsfort_post_view_count(); ?>
                                                </div>

                                            </div>
                                        </div>

                                    </div>
                                </article>
                            </div>
                            <?php
                            $post_count++;

                        } ?>

                        <a href="javascript:void(0)" class="newsfort-skip-link-end"></a>

                    </div>
               </div>
            </div>

            <?php
            wp_reset_postdata();

        endif;
    }

endif;

if( !function_exists('newsfort_footer_content_widget') ):

    function newsfort_footer_content_widget(){

        $newsfort_default = newsfort_get_default_theme_options();
        if (is_active_sidebar('newsfort-footer-widget-0') || 
            is_active_sidebar('newsfort-footer-widget-1') || 
            is_active_sidebar('newsfort-footer-widget-2')):
            $x = 1;
            $footer_sidebar = 0;
            do {
                if ($x == 3 && is_active_sidebar('newsfort-footer-widget-2')) {
                    $footer_sidebar++;
                }
                if ($x == 2 && is_active_sidebar('newsfort-footer-widget-1')) {
                    $footer_sidebar++;
                }
                if ($x == 1 && is_active_sidebar('newsfort-footer-widget-0')) {
                    $footer_sidebar++;
                }
                $x++;
            } while ($x <= 3);
            if ($footer_sidebar == 1) {
                $footer_sidebar_class = 12;
            } elseif ($footer_sidebar == 2) {
                $footer_sidebar_class = 6;
            } else {
                $footer_sidebar_class = 4;
            }
            $footer_column_layout = absint(get_theme_mod('footer_column_layout', $newsfort_default['footer_column_layout'])); ?>

            <div class="footer-widgetarea">
                <div class="wrapper">
                    <div class="column-row">
                        <?php if (is_active_sidebar('newsfort-footer-widget-0')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-12">
                                <?php dynamic_sidebar('newsfort-footer-widget-0'); ?>
                            </div>
                        <?php endif; ?>

                        <?php if (is_active_sidebar('newsfort-footer-widget-1')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-12">
                                <?php dynamic_sidebar('newsfort-footer-widget-1'); ?>
                            </div>
                        <?php endif; ?>

                        <?php if (is_active_sidebar('newsfort-footer-widget-2')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-12">
                                <?php dynamic_sidebar('newsfort-footer-widget-2'); ?>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        <?php
        endif;

    }

endif;

add_action( 'newsfort_footer_content_action','newsfort_footer_content_widget',10 );

if( !function_exists('newsfort_footer_content_info') ):

    /**
     * Footer Copyright Area
    **/
    function newsfort_footer_content_info(){

        $newsfort_default = newsfort_get_default_theme_options(); ?>
        <div class="site-info">
            <div class="wrapper">
                <div class="column-row">
                    <div class="column column-5 column-sm-12 mb-sm-15">
                        <div class="footer-copyright">
                            <?php
                            $footer_copyright_text = wp_kses_post( get_theme_mod( 'footer_copyright_text', $newsfort_default['footer_copyright_text'] ) );
                            echo esc_html__('Copyright ', 'newsfort') . '&copy ' . absint(date('Y')) . ' <a href="' . esc_url(home_url('/')) . '" title="' . esc_attr(get_bloginfo('name', 'display')) . '" ><span>' . esc_html( get_bloginfo( 'name', 'display' ) ) . '. </span></a> ' . esc_html( $footer_copyright_text );

                            echo '<br>';
                            echo esc_html__('Theme: ', 'newsfort') . 'NewsFort ' . esc_html__('By ', 'newsfort') . '<a href="' . esc_url('https://www.themeinwp.com/theme/newsfort') . '"  title="' . esc_attr__('Themeinwp', 'newsfort') . '" target="_blank" rel="author"><span>' . esc_html__('Themeinwp. ', 'newsfort') . '</span></a>';
                            echo esc_html__('Powered by ', 'newsfort') . '<a href="' . esc_url('https://wordpress.org') . '" title="' . esc_attr__('WordPress', 'newsfort') . '" target="_blank"><span>' . esc_html__('WordPress.', 'newsfort') . '</span></a>';
                            
                            ?>
                        </div>
                    </div>
                    <div class="column column-7 column-sm-12">

                        <?php if( has_nav_menu( 'newsfort-footer-menu' ) ){ ?>
                            <div class="footer-nav">
                                <?php wp_nav_menu(array(
                                    'theme_location' => 'newsfort-footer-menu',
                                    'container' => 'div',
                                    'container_class' => 'navigation-area'
                                )); ?>
                            </div>
                        <?php } ?>
                    </div>
                </div>
            </div>
        </div>

    <?php
    }

endif;

add_action( 'newsfort_footer_content_action','newsfort_footer_content_info',20 );


if( !function_exists('newsfort_footer_go_to_top') ):

    // Scroll to Top render content
    function newsfort_footer_go_to_top(){

        $newsfort_default = newsfort_get_default_theme_options();
        $ed_scroll_top_button = get_theme_mod( 'ed_scroll_top_button', $newsfort_default['ed_scroll_top_button'] );

        if( $ed_scroll_top_button ){
            
            ?>
            <button type="button" class="scroll-up">

                <div class="scroll-up-icon scroll-up-arrow"></div>
                <div class="scroll-up-icon scroll-up-line"></div>

                <?php newsfort_the_theme_svg('scroll-progress-circle' ); ?>
            </button>
            <?php

        }

    }

endif;

add_action( 'newsfort_footer_content_action','newsfort_footer_go_to_top',30 );


if( !function_exists('newsfort_color_schema_color') ):

    function newsfort_color_schema_color( $current_color ){

        $newsfort_default = newsfort_get_default_theme_options();
        
        $colors_schema = array(

            'default' => array(
                'background_color' => $newsfort_default['default_bg_color'],
            ),

            'dark' => array(
                'background_color' => $newsfort_default['dark_bg_color'],
            ),

        );

        if( isset( $colors_schema[$current_color] ) ){
            
            return $colors_schema[$current_color];

        }

        return;

    }

endif;

if ( ! function_exists( 'newsfort_color_schema_color_action' ) ) :
    function newsfort_color_schema_color_action() {

        $current_color = isset( $_POST['currentColor'] ) ? sanitize_text_field( wp_unslash( $_POST['currentColor'] ) ) : '';

        $color_schemes = newsfort_color_schema_color( $current_color );

        if ( $color_schemes ) {
            echo json_encode( $color_schemes );
        }

        wp_die();

    }

endif;

add_action( 'wp_ajax_nopriv_newsfort_color_schema_color', 'newsfort_color_schema_color_action' );
add_action( 'wp_ajax_newsfort_color_schema_color', 'newsfort_color_schema_color_action' );

if( !function_exists( 'newsfort_post_view_count' ) ):

    function newsfort_post_view_count(){

        $newsfort_default = newsfort_get_default_theme_options();
        $ed_post_views = get_theme_mod( 'ed_post_views', $newsfort_default['ed_post_views'] );
        $twp_be_settings = get_option('twp_be_options_settings');
        $twp_be_enable_post_visit_tracking = isset( $twp_be_settings[ 'twp_be_enable_post_visit_tracking' ] ) ? esc_html( $twp_be_settings[ 'twp_be_enable_post_visit_tracking' ] ) : '';
        if( $twp_be_enable_post_visit_tracking && class_exists( 'Booster_Extension_Class' ) ): ?>

            <div class="entry-meta-item entry-meta-views">
                <div class="entry-meta-wrapper">
                    
                        <span class="entry-meta-icon views-icon">
                            <?php newsfort_the_theme_svg('viewer'); ?>
                        </span>
                        <a href="<?php the_permalink(); ?>">
                            <span class="post-view-count">
                               <?php
                               echo do_shortcode('[booster-extension-visit-count count_only="count" label="'.esc_html__('Views','newsfort').'"]');
                               ?>
                            </span>
                         </a>
                </div>
            </div>
        
        <?php
        endif;
    }
endif;

if( !function_exists( 'newsfort_post_like_dislike' ) ):

    function newsfort_post_like_dislike(){

        $newsfort_ed_post_like_dislike = esc_html( get_post_meta( get_the_ID(), 'newsfort_ed_post_like_dislike', true ) );
        if( class_exists( 'Booster_Extension_Class' ) && !$newsfort_ed_post_like_dislike ): ?>

            <div class="entry-meta-item entry-meta-like-dislike">
                <div class="entry-meta-wrapper">
                    <?php echo do_shortcode('[booster-extension-like-dislike]'); ?>
                </div>
            </div>
        
        <?php
        endif;
    }
endif;

add_action('wp_ajax_newsfort_masonry_posts', 'newsfort_masonry_posts_callback');
add_action('wp_ajax_nopriv_newsfort_masonry_posts', 'newsfort_masonry_posts_callback');

if( !function_exists( 'newsfort_masonry_posts_callback' ) ):
// Masonry Post Ajax Call Function.

    function newsfort_masonry_posts_callback() {

        if(  isset( $_POST[ '_wpnonce' ] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST[ '_wpnonce' ] ) ), 'newsfort_ajax_nonce' ) && isset( $_POST['paged_current'] ) && isset( $_POST['section_category'] ) ){

            $paged_current = absint( wp_unslash( $_POST['paged_current'] ) );
            $section_category = sanitize_text_field( wp_unslash( $_POST['section_category'] ) );

            $masonry_post_query = new WP_Query( array( 'post_type' => 'post','posts_per_page' => 8,'post__not_in' => get_option("sticky_posts"), 'category_name' => esc_html( $section_category ), 'paged'=>$paged_current ) );

            $class_1 = isset( $_POST[ 'class_1' ] ) ? sanitize_text_field( wp_unslash( $_POST[ 'class_1' ] ) ) : '';
            

            if( $masonry_post_query ->have_posts() ): ?>

                <?php
                while( $masonry_post_query ->have_posts() ){
                    $masonry_post_query ->the_post();

                    $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'large'); 
                    ob_start(); ?>

                    <div class="column <?php echo $class_1; ?> column-sm-6 column-xs-12 twp-masonary-item twp-masonary-item-new">

                        <?php

                        if( get_post_format() == 'video' ){

                            $video_autoplay = esc_attr( get_post_meta(get_the_ID(), 'twp_video_autoplay', true) );
                            if( $video_autoplay == '' || $video_autoplay == 'global' ){

                                $video_autoplay = isset( $_POST[ 'vidAutoplay' ] ) ? sanitize_text_field( wp_unslash( $_POST[ 'vidAutoplay' ] ) ) : '';

                                if( $video_autoplay == '' || $video_autoplay == 'global' ){
                                    $video_autoplay = get_theme_mod( 'ed_autoplay', $newsfort_default['ed_autoplay'] );
                                }

                            }

                            $ratio_value = get_post_meta( get_the_ID(), 'twp_aspect_ratio', true );
                            if( $ratio_value == '' || $ratio_value == 'global' ){
                                
                                $ratio_value = isset( $_POST[ 'vidRatio' ] ) ? sanitize_text_field( wp_unslash( $_POST[ 'vidRatio' ] ) ) : '';

                                if( $ratio_value == '' || $ratio_value == 'global' ){
                                    $ratio_value = get_theme_mod( 'post_video_aspect_ration', $newsfort_default['post_video_aspect_ration'] );
                                }

                            }

                            newsfort_video_content_render( $class1 = 'theme-post-2-'.$paged_current, $class2 = 'video-id-2-'.$paged_current, $class3 = 'video-main-wraper-2-'.$paged_current, $ratio_value, $video_autoplay );

                        }else{
                            
                            get_template_part( 'template-parts/content', get_post_format() );

                        } ?>

                    </div>

                <?php $output['content'][] = ob_get_clean();
                }
                wp_send_json_success($output);
                wp_reset_postdata(); ?>

            <?php
            endif;
            
        }

        wp_die();
    }

endif;

add_action('wp_ajax_newsfort_tab_posts_callback', 'newsfort_tab_posts_callback');
add_action('wp_ajax_nopriv_newsfort_tab_posts_callback', 'newsfort_tab_posts_callback');

if( !function_exists( 'newsfort_tab_posts_callback' ) ):
    // Masonry Post Ajax Call Function.

    function newsfort_tab_posts_callback() {

        if(  isset( $_POST[ '_wpnonce' ] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST[ '_wpnonce' ] ) ), 'newsfort_ajax_nonce' ) && isset( $_POST['category'] ) && isset( $_POST['currencBlock'] ) && isset( $_POST['currencBlock'] ) ){

            $category = sanitize_text_field( wp_unslash( $_POST['category'] ) );

            $tab_post_query = new WP_Query( 
                array( 
                    'post_type' => 'post',
                    'posts_per_page' => 6,
                    'post__not_in' => get_option("sticky_posts"),
                    'category_name' => esc_html( $category ),
                    'post_status' => 'publish'
                ) 
            );

            $tab_post_query_1 = new WP_Query( 
                array( 
                    'post_type' => 'post',
                    'posts_per_page' => 6,
                    'post__not_in' => get_option("sticky_posts"),
                    'category_name' => esc_html( $category ),
                    'post_status' => 'publish'
                ) 
            );

            if( $tab_post_query ->have_posts() ): ?>

                    <div class="column-row">

                        <div class="column column-5 column-xs-12">

                        <?php
                        $post_count = 1;
                        while ($tab_post_query->have_posts()) {
                            $tab_post_query->the_post();

                            $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'newsfort-500-300');
                            $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>
                            <article id="theme-post-<?php the_ID(); ?>" <?php post_class('news-article post-thumb post-thumb-tiles'); ?>>
                                <div class="data-bg data-bg-medium thumb-overlay img-hover-slide" data-background="<?php echo esc_url($featured_image); ?>">

                                    <?php
                                    $format = get_post_format(get_the_ID()) ?: 'standard';
                                    $icon = newsfort_post_format_icon($format);
                                    if (!empty($icon)) { ?>
                                        <span class="top-right-icon">
                                            <?php echo newsfort_svg_escape($icon); ?>
                                        </span>
                                    <?php } ?>
                                    <a class="img-link" href="<?php the_permalink(); ?>" tabindex="0"></a>
                                    <div class="article-content article-content-overlay">
                                        <div class="entry-meta">
                                            <?php newsfort_entry_footer($cats = true, $tags = false, $edits = false, $text = false, $icon = false); ?>
                                        </div>
                                        <h3 class="entry-title entry-title-medium">
                                            <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark"
                                               title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a>
                                        </h3>
                                        <div class="entry-meta">
                                            <?php newsfort_posted_on(); ?>
                                            <?php newsfort_post_view_count(); ?>
                                        </div>
                                    </div>
                                </div>
                            </article>

                            <?php
                            if( $post_count == 2 ){ 
                                break;
                            }

                            $post_count++;

                        }
                        wp_reset_postdata(); ?>

                        </div>

                        <div class="column column-7 column-xs-12">
                            <div class="content-main">

                                <?php
                                $post_count = 1;
                                while ($tab_post_query_1->have_posts()) {
                                    $tab_post_query_1->the_post();

                                        if( $post_count != 1 && $post_count != 2 ){

                                            $featured_image = wp_get_attachment_image_src( get_post_thumbnail_id(), 'large' );
                                            $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>

                                            <div class="content-list">
                                                <article id="theme-post-<?php the_ID(); ?>" <?php post_class('news-article tab-news-article news-article-bg'); ?>>

                                                        <?php if ($featured_image) { ?>
                                                            <div class="data-bg thumb-overlay img-hover-slide" data-background="<?php echo esc_url($featured_image); ?>">

                                                                <?php
                                                                $format = get_post_format(get_the_ID()) ?: 'standard';
                                                                $icon = newsfort_post_format_icon($format);
                                                                if (!empty($icon)) { ?>
                                                                    <span class="top-right-icon">
                                                                        <?php echo newsfort_svg_escape($icon); ?>
                                                                    </span>
                                                                <?php } ?>
                                                                <a class="img-link" href="<?php the_permalink(); ?>" tabindex="0"></a>
                                                                
                                                            </div>
                                                        <?php } ?>

                                                            <div class="article-content article-content-1">
                                                                <h3 class="entry-title entry-title-small">
                                                                    <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a>
                                                                </h3>
                                                                <div class="entry-meta">
                                                                    <?php newsfort_posted_on(); ?>
                                                                    <?php newsfort_post_view_count(); ?>
                                                                </div>
                                                            </div>
                                                </article>
                                            </div>

                                        <?php
                                        }

                                        $post_count++;

                                } ?>

                            </div>
                        </div>


                    </div>

                <?php
                wp_reset_postdata();

            endif;
        }

        wp_die();
    }

endif;

if( !function_exists( 'newsfort_header_ticker_posts' ) ):

    function newsfort_header_ticker_posts(){

        $newsfort_default = newsfort_get_default_theme_options();
        $ed_header_ticker_posts = get_theme_mod( 'ed_header_ticker_posts',$newsfort_default['ed_header_ticker_posts'] );
        $ed_header_ticker_posts_title = get_theme_mod( 'ed_header_ticker_posts_title',$newsfort_default['ed_header_ticker_posts_title'] );
        $newsfort_header_ticker_cat = get_theme_mod( 'newsfort_header_ticker_cat' );
        $slider_autoplay = get_theme_mod( 'ed_ticker_slider_autoplay',$newsfort_default['ed_ticker_slider_autoplay'] );
        $ticker_slider_wide_layout = get_theme_mod( 'ed_ticker_slider_wide_layout',$newsfort_default['ed_ticker_slider_wide_layout'] );
        
        $class = 'wrapper';

        if( $ticker_slider_wide_layout ){
            $class = 'wrapper-fluid';
        }

        if( $slider_autoplay ){
            $autoplay = 'true';
        }else{
            $autoplay = 'false';
        }
        
        if( is_rtl() ) {
            $rtl = 'true';
        }else{
            $rtl = 'false';
        }

        if( $ed_header_ticker_posts ){ ?>

            <div class="theme-ticker-area hide-no-js">
                <div class="<?php echo $class; ?>">
                    <div class="ticker-area clear">

                        <?php if( $ed_header_ticker_posts_title ){ ?>
                            <div class="ticker-title">
                                <span class="ticker-title-label"><?php echo esc_html( $ed_header_ticker_posts_title ); ?></span>
                            </div>
                        <?php } ?>

                        <?php
                        $ticker_posts_query = new WP_Query(array('post_type' => 'post', 'posts_per_page' => 10, 'post__not_in' => get_option("sticky_posts"), 'category_name' => esc_html($newsfort_header_ticker_cat)));

                        if( $ticker_posts_query->have_posts() ): ?>

                            <div class="ticker-content">
                                <div class="ticker-slides" data-slick='{"autoplay": <?php echo esc_attr( $autoplay ); ?>, "rtl": <?php echo esc_attr( $rtl ); ?>}'>

                                    <?php 
                                    while( $ticker_posts_query->have_posts() ):
                                        $ticker_posts_query->the_post();

                                        $featured_image = wp_get_attachment_image_src( get_post_thumbnail_id(), 'newsfort-150-150' ); ?>

                                        <div class="ticker-item">
                                            <article id="theme-post-<?php the_ID(); ?>" <?php post_class( 'news-article' ); ?>>
                                                
                                                <?php if( isset( $featured_image[0] ) && $featured_image[0] ){ ?>
                                                    <div class="post-thumbnail">
                                                        <div class="img-hover-scale">
                                                            <a href="<?php the_permalink(); ?>">
                                                                <img title="<?php the_title_attribute(); ?>" alt="<?php the_title_attribute(); ?>" src="<?php echo esc_url( $featured_image[0] ); ?>">
                                                            </a>
                                                        </div>
                                                    </div>
                                                <?php } ?>

                                                <div class="article-content">
                                                    <h3 class="entry-title entry-title-xsmall">
                                                        <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark" title="<?php the_title_attribute(); ?>">
                                                            <?php  echo esc_html( wp_trim_words( get_the_title(),10,'...' ) ); ?>
                                                        </a>
                                                    </h3>
                                                </div>

                                            </article>
                                        </div>

                                    <?php 
                                    endwhile; ?>

                                </div>

                                <div class="ticker-controls">
                                    <div class="title-controls">
                                        <button type="button" class="slide-btn theme-aria-button slide-prev-ticker">
                                            <span class="btn__content" tabindex="-1">
                                                <?php newsfort_the_theme_svg('chevron-left'); ?>
                                            </span>
                                        </button>

                                        <button type="button" class="slide-btn theme-aria-button ticker-control ticker-control-play">
                                            <span class="btn__content" tabindex="-1">
                                                <?php newsfort_the_theme_svg('play'); ?>
                                            </span>
                                        </button>

                                        <button type="button" class="slide-btn theme-aria-button ticker-control ticker-control-pause pp-button-active">
                                            <span class="btn__content" tabindex="-1">
                                                <?php newsfort_the_theme_svg('pause'); ?>
                                            </span>
                                        </button>

                                        <button type="button" class="slide-btn theme-aria-button slide-next-ticker">
                                            <span class="btn__content" tabindex="-1">
                                                <?php newsfort_the_theme_svg('chevron-right'); ?>
                                            </span>
                                        </button>
                                    </div>
                                </div>
                            </div>

                            <?php 
                            wp_reset_postdata();
                        endif; ?>

                    </div>
                </div>
            </div>

        <?php
        }

    }

endif;




if( !function_exists('newsfort_404_posts') ):

    function newsfort_404_posts(){

        $lead_post_query = new WP_Query( array('post_type' => 'post', 'posts_per_page' => 3,'post__not_in' => get_option("sticky_posts") ) );
        
        if( $lead_post_query ->have_posts() ): ?>
            <div class="theme-block theme-block-lead theme-block-notop error-block error-block-bottom">
                <div class="wrapper">
                    <div class="column-row column-row-small">
                            <?php
                            while ($lead_post_query->have_posts()) {
                                $lead_post_query->the_post();

                                $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'large');
                                $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : '';
                                ?>

                                <div class="column column-6 column-sm-12 mb-sm-15 column-order-1">
                                    <article id="theme-post-<?php the_ID(); ?>" <?php post_class('post-thumb news-article news-article-bg'); ?>>
                                        <?php if ($featured_image) { ?>
                                            <div class="data-bg data-bg-medium thumb-overlay thumb-overlay-darker img-hover-slide" data-background="<?php echo esc_url($featured_image); ?>">
                                                <?php
                                                $format = get_post_format(get_the_ID()) ?: 'standard';
                                                $icon = newsfort_post_format_icon($format);
                                                if (!empty($icon)) { ?>
                                                    <span class="top-right-icon">
                                                            <?php echo newsfort_svg_escape( $icon ); ?>
                                                        </span>
                                                <?php } ?>
                                                <a class="img-link" href="<?php the_permalink(); ?>" tabindex="0"></a>
                                            </div>

                                        <?php } ?>

                                        <div class="article-content">

                                            <div class="entry-meta">
                                                <?php newsfort_entry_footer($cats = true, $tags = false, $edits = false, $text = false, $icon = false); ?>
                                            </div>

                                            <h3 class="entry-title entry-title-medium">
                                                <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark"
                                                   title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a>
                                            </h3>

                                            <div class="entry-meta">
                                                <?php newsfort_posted_on(); ?>
                                                <?php newsfort_post_view_count(); ?>
                                                <?php newsfort_posted_by(); ?>
                                            </div>

                                            <div class="entry-content entry-content-muted entry-content-small">

                                                <?php
                                                if (has_excerpt()) {

                                                    the_excerpt();

                                                } else {

                                                    echo '<p>';
                                                    echo esc_html( wp_trim_words( get_the_content(),30,'...' ) );
                                                    echo '</p>';

                                                } ?>

                                            </div>

                                        </div>
                                    </article>
                                </div>

                                <?php
                                break;

                            } ?>

                            <div class="column column-6 column-sm-12 column-order-2">
                                <div class="column-row column-row-small">
                                    <?php
                                    $i = 1;
                                    while ($lead_post_query->have_posts()) {
                                        $lead_post_query->the_post();

                                        $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'large');
                                        $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : '';
                                        ?>
                                        <div class="column column-6 mb-xs-15 column-xs-12">
                                            <div class="content-main content-main-bg">
                                                <div class="content-list">
                                                    <article
                                                            id="theme-post-<?php the_ID(); ?>" <?php post_class('news-article'); ?>>

                                                        <?php if ($featured_image) { ?>
                                                            <div class="post-thumbnail">
                                                                <div class="img-hover-scale">

                                                                    <?php
                                                                    $format = get_post_format(get_the_ID()) ?: 'standard';
                                                                    $icon = newsfort_post_format_icon($format);
                                                                    if (!empty($icon)) { ?>
                                                                        <span class="top-right-icon"><?php echo newsfort_svg_escape( $icon ); ?></span>
                                                                    <?php } ?>

                                                                    <a href="<?php the_permalink(); ?>" tabindex="0">
                                                                        <img title="<?php the_title_attribute(); ?>"
                                                                             alt="<?php the_title_attribute(); ?>"
                                                                             src="<?php echo esc_url($featured_image); ?>">
                                                                    </a>

                                                                </div>
                                                            </div>
                                                        <?php } ?>

                                                        <div class="article-content">
                                                            <div class="entry-meta">
                                                                <?php newsfort_entry_footer($cats = true, $tags = false, $edits = false, $text = false, $icon = false); ?>
                                                            </div>

                                                            <h3 class="entry-title entry-title-small">
                                                                <a href="<?php the_permalink(); ?>"
                                                                   rel="bookmark"><?php the_title(); ?></a>
                                                            </h3>

                                                            <div class="entry-meta">
                                                                <?php newsfort_posted_on(); ?>
                                                                <?php newsfort_post_view_count(); ?>
                                                            </div>

                                                            <div class="entry-content entry-content-muted entry-content-small">

                                                                <?php
                                                                if (has_excerpt()) {

                                                                    the_excerpt();

                                                                } else {

                                                                    echo '<p>';
                                                                    echo esc_html( wp_trim_words( get_the_content(),20,'...' ) );
                                                                    echo '</p>';

                                                                } ?>

                                                            </div>
                                                        </div>

                                                    </article>
                                                </div>
                                            </div>
                                        </div>

                                        <?php
                                        $i++;

                                    } ?>

                                </div>
                            </div>
                    </div>
                </div>
            </div>
        <?php
        wp_reset_postdata();
        endif;

    }

endif;

if( class_exists('WooCommerce') ){

    remove_action('woocommerce_sidebar','woocommerce_get_sidebar');
    add_action('woocommerce_before_main_content','newsfort_woo_before_main_content',5);
    add_action('woocommerce_after_main_content','newsfort_woo_after_main_content',15);

}
if( !function_exists('newsfort_woo_before_main_content') ):

    function newsfort_woo_before_main_content(){

        echo '<div class="wrapper">';
        echo '<div class="column-row">';

    }

endif;

if( !function_exists('newsfort_woo_after_main_content') ):

    function newsfort_woo_after_main_content(){

        $newsfort_default = newsfort_get_default_theme_options();
        $sidebar = esc_attr( get_theme_mod( 'global_sidebar_layout', $newsfort_default['global_sidebar_layout'] ) );
        if( $sidebar != 'no-sidebar' ){

            get_sidebar();
            
        }

        echo '</div>';
        echo '</div>';

    }

endif;


if( !function_exists('newsfort_content_loading') ){

    function newsfort_content_loading(){ ?>

        <div class="content-loading-status">
            <div class="theme-ajax-loader"></div>
            <div class="screen-reader-text">
                <?php esc_html_e('Content Loading','newsfort'); ?>
            </div>
        </div>
    
    <?php
    }
}


function newsfort_hex2rgb( $colour,$opacity = 1 ) {

    if ( $colour[0] == '#' ) {
            $colour = substr( $colour, 1 );
    }
    if ( strlen( $colour ) == 6 ) {
            list( $r, $g, $b ) = array( $colour[0] . $colour[1], $colour[2] . $colour[3], $colour[4] . $colour[5] );
    } elseif ( strlen( $colour ) == 3 ) {
            list( $r, $g, $b ) = array( $colour[0] . $colour[0], $colour[1] . $colour[1], $colour[2] . $colour[2] );
    } else {
            return false;
    }
    $r = hexdec( $r );
    $g = hexdec( $g );
    $b = hexdec( $b );
    return 'rgba('.$r.','.$g.','.$b.','.$opacity.')';

}

if( !function_exists( 'newsfort_top_tages' ) ):

    function newsfort_top_tages() {

        $latest_post_query = new WP_Query( array( 'post_type' => 'post', 'posts_per_page' => 50, 'post__not_in' => get_option("sticky_posts") ) );
        $tag_lists = array();

        if( $latest_post_query->have_posts() ):

            while( $latest_post_query->have_posts() ):
                $latest_post_query->the_post();

                $tags = get_the_tags( get_the_ID() );

                if( $tags ){

                    foreach( $tags as $tag ){

                        if( !in_array($tag->term_id, $tag_lists) ){
                            
                            $tag_lists[ $tag->term_id ] = $tag->count;

                        }

                    }

                }

            endwhile;

        endif;

        arsort( $tag_lists);

        $newsfort_default = newsfort_get_default_theme_options();
        $ed_header_tags = get_theme_mod( 'ed_header_tags',$newsfort_default['ed_header_tags'] );

        if( $ed_header_tags ){

            $ed_header_tags_title = get_theme_mod( 'ed_header_tags_title',$newsfort_default['ed_header_tags_title'] );
            $ed_header_tags_count = get_theme_mod( 'ed_header_tags_count',$newsfort_default['ed_header_tags_count'] );
            $ed_tags_wide_layout = get_theme_mod( 'ed_tags_wide_layout',$newsfort_default['ed_tags_wide_layout'] );
        
            $class = 'wrapper';

            if( $ed_tags_wide_layout ){
                $class = 'wrapper-fluid';
            }
            ?>
            <div class="theme-tags-area">
                <div class="<?php echo $class; ?>">
                    <div class="tags-area clear">
                        
                        <?php if( $ed_header_tags_title ){ ?>
                            <div class="tags-title">
                                <span><?php echo esc_html( $ed_header_tags_title ); ?></span>
                            </div>
                        <?php } ?>


                        <div class="tags-content">
                            <?php
                            if ($tag_lists) {
                                $count  = 1;
                                foreach( $tag_lists as $key => $value ){


                                    $tag = get_tag($key); // <-- your tag ID
                                    ?>
                                    <a href="<?php echo esc_url(get_tag_link($key)); ?>" class="tags-title-label"><?php echo esc_html($tag->name); ?></a>
                                    <?php

                                    if( $count == $ed_header_tags_count ){ break; }
                                    $count++;
                                }
                            }
                            ?>
                        </div>
                    </div>
                </div>
            </div>

            <?php
        }

    }

endif;

if( class_exists( 'Booster_Extension_Class' ) ){

    add_filter('booster_extemsion_content_after_filter','newsfort_after_content_pagination');

}

if( !function_exists('newsfort_after_content_pagination') ):

    function newsfort_after_content_pagination($after_content){

        $pagination_single = wp_link_pages( array(
                    'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'newsfort' ),
                    'after'  => '</div>',
                    'echo' => false
                ) );

        $after_content =  $pagination_single.$after_content;

        return $after_content;

    }

endif;

if( ! function_exists( 'newsfort_iframe_escape' ) ):
    
    /** Escape Iframe **/
    function newsfort_iframe_escape( $input ){

        $all_tags = array(
            'iframe'=>array(
                'width'=>array(),
                'height'=>array(),
                'src'=>array(),
                'frameborder'=>array(),
                'allow'=>array(),
                'allowfullscreen'=>array(),
            ),
            'video'=>array(
                'width'=>array(),
                'height'=>array(),
                'src'=>array(),
                'style'=>array(),
                'controls'=>array(),
            )
        );

        return wp_kses($input,$all_tags);
        
    }

endif;

if( !function_exists('newsfort_search_offcanvas_icon_render') ):

    function newsfort_search_offcanvas_icon_render(){

        $newsfort_default = newsfort_get_default_theme_options();
        $ed_header_responsive_menu = get_theme_mod('ed_header_responsive_menu', $newsfort_default['ed_header_responsive_menu']);
        $ed_header_trending_news = get_theme_mod('ed_header_trending_news', $newsfort_default['ed_header_trending_news']); ?>

        <div class="navbar-controls hide-no-js">
            <?php
            $ed_header_search = get_theme_mod('ed_header_search', $newsfort_default['ed_header_search']);
            if ($ed_header_search) { ?>
                <button type="button" class="navbar-control navbar-control-search">
                    <span class="navbar-control-trigger" tabindex="-1"><?php newsfort_the_theme_svg('search'); ?></span>
                </button>
            <?php } ?>

            <button type="button" class="navbar-control navbar-control-offcanvas">
                <span class="navbar-control-trigger" tabindex="-1"><?php newsfort_the_theme_svg('menu'); ?></span>
            </button>

            <?php if( $ed_header_trending_news ){
                $ed_header_trending_posts_title = get_theme_mod('ed_header_trending_posts_title', $newsfort_default['ed_header_trending_posts_title']);  ?>
                <button type="button" class="navbar-control navbar-control-trending-news">
                    <span class="navbar-control-trigger" tabindex="-1">
                        <span class="navbar-controller">
                            <span class="navbar-control-icon">
                                <?php newsfort_the_theme_svg('blaze'); ?>
                            </span>
                            <span class="navbar-control-label">
                                <?php echo esc_html( $ed_header_trending_posts_title ); ?>
                            </span>
                        </span>
                    </span>
                </button>

            <?php } ?>

        </div>

    <?php
    }

endif;



if( !function_exists('newsfort_video_aspect_ratio') ):

    function newsfort_video_aspect_ratio(){

        return $newsfort_video_aspect_ratio = array(
            'global' => esc_html__( 'Global', 'newsfort' ),
            'default' => esc_html__( 'Default', 'newsfort' ),
            'square' => esc_html__( 'Square', 'newsfort' ),
            'portrait' => esc_html__( 'Portrait', 'newsfort' ),
            'landscape' => esc_html__( 'Landscape', 'newsfort' ),
        );

    }

endif;

if( !function_exists('newsfort_video_autoplay') ):

    function newsfort_video_autoplay(){

        return $newsfort_video_autoplay = array(
            'global' => esc_html__( 'Global', 'newsfort' ),
            'autoplay-disable' => esc_html__( 'Disable Autoplay', 'newsfort' ),
            'autoplay-enable' => esc_html__( 'Enable Autoplay', 'newsfort' ),
            
        );

    }

endif;

add_filter('comment_form_defaults','newsfort_comment_title_callback');

if( !function_exists('newsfort_comment_title_callback') ):


    function newsfort_comment_title_callback($defaults){

        $defaults['title_reply_before'] = '<header class="block-title-wrapper"><h3 class="block-title">';
        $defaults['title_reply_after'] = '</h3></header>';
        return $defaults;

    }

endif;