<?php
/**
* Custom Functions.
*
* @package NewsFort
*/

if( !function_exists( 'newsfort_sanitize_layout_option' ) ) :

    // Sidebar Option Sanitize.
    function newsfort_sanitize_layout_option( $newsfort_input ){

        $newsfort_metabox_options = array( 'default','boxed','widerwidth' );
        if( in_array( $newsfort_input,$newsfort_metabox_options ) ){

            return $newsfort_input;

        }

        return;

    }

endif;

if( !function_exists( 'newsfort_sanitize_sidebar_option' ) ) :

    // Sidebar Option Sanitize.
    function newsfort_sanitize_sidebar_option( $newsfort_input ){

        $newsfort_metabox_options = array( 'global-sidebar','left-sidebar','right-sidebar','no-sidebar' );
        if( in_array( $newsfort_input,$newsfort_metabox_options ) ){

            return $newsfort_input;

        }

        return;

    }

endif;

if( !function_exists( 'newsfort_sanitize_single_pagination_layout' ) ) :

    // Sidebar Option Sanitize.
    function newsfort_sanitize_single_pagination_layout( $newsfort_input ){

        $newsfort_single_pagination = array( 'no-navigation','norma-navigation','ajax-next-post-load' );
        if( in_array( $newsfort_input,$newsfort_single_pagination ) ){

            return $newsfort_input;

        }

        return;

    }

endif;

if( !function_exists( 'newsfort_sanitize_archive_layout' ) ) :

    // Sidebar Option Sanitize.
    function newsfort_sanitize_archive_layout( $newsfort_input ){

        $newsfort_archive_option = array( 'default','full','grid','masonry' );
        if( in_array( $newsfort_input,$newsfort_archive_option ) ){

            return $newsfort_input;

        }

        return;

    }

endif;

if( !function_exists( 'newsfort_sanitize_header_layout' ) ) :

    // Sidebar Option Sanitize.
    function newsfort_sanitize_header_layout( $newsfort_input ){

        $newsfort_header_options = array( 'layout-1','layout-2','layout-3' );
        if( in_array( $newsfort_input,$newsfort_header_options ) ){

            return $newsfort_input;

        }

        return;

    }

endif;

if( !function_exists( 'newsfort_sanitize_single_post_layout' ) ) :

    // Single Layout Option Sanitize.
    function newsfort_sanitize_single_post_layout( $newsfort_input ){

        $newsfort_single_layout = array( 'layout-1','layout-2' );
        if( in_array( $newsfort_input,$newsfort_single_layout ) ){

            return $newsfort_input;

        }

        return;

    }

endif;

if ( ! function_exists( 'newsfort_sanitize_checkbox' ) ) :

	/**
	 * Sanitize checkbox.
	 */
	function newsfort_sanitize_checkbox( $newsfort_checked ) {

		return ( ( isset( $newsfort_checked ) && true === $newsfort_checked ) ? true : false );

	}

endif;


if ( ! function_exists( 'newsfort_sanitize_select' ) ) :

    /**
     * Sanitize select.
     */
    function newsfort_sanitize_select( $newsfort_input, $newsfort_setting ) {

        // Ensure input is a slug.
        $newsfort_input = sanitize_text_field( $newsfort_input );

        // Get list of choices from the control associated with the setting.
        $choices = $newsfort_setting->manager->get_control( $newsfort_setting->id )->choices;

        // If the input is a valid key, return it; otherwise, return the default.
        return ( array_key_exists( $newsfort_input, $choices ) ? $newsfort_input : $newsfort_setting->default );

    }

endif;

if ( ! function_exists( 'newsfort_sanitize_repeater' ) ) :
    
    /**
    * Sanitise Repeater Field
    */
    function newsfort_sanitize_repeater($input){
        $input_decoded = json_decode( $input, true );
        
        if(!empty($input_decoded)) {

            foreach ($input_decoded as $boxes => $box ){

                foreach ($box as $key => $value){

                    if( $key == 'section_ed' 
                        || $key == 'ed_tab' 
                        || $key == 'ed_arrows_carousel' 
                        || $key == 'ed_dots_carousel' 
                        || $key == 'ed_autoplay_carousel' 
                        || $key == 'ed_flip_column' 
                        || $key == 'ed_ribbon_bg'
                    ){

                        $input_decoded[$boxes][$key] = newsfort_sanitize_repeater_ed( $value );

                    }elseif( $key == 'home_section_type' ){

                        $input_decoded[$boxes][$key] = newsfort_sanitize_home_sections( $value );

                    }elseif( $key == 'ribbon_bg_color_schema' ){

                        $input_decoded[$boxes][$key] = newsfort_sanitize_ribbon_bg( $value );

                    }elseif( $key == 'category_color' ){

                        $input_decoded[$boxes][$key] = sanitize_hex_color( $value );

                    }elseif( $key == 'bg_image_size' ){

                        $input_decoded[$boxes][$key] =  newsfort_sanitize_bg_image_size( $value );

                    }elseif( $key == 'tiles_post_per_page' ){

                        $input_decoded[$boxes][$key] =  absint( $value );

                    }elseif( $key == 'advertise_image' || $key == 'advertise_link' ){

                         $input_decoded[$boxes][$key] = esc_url_raw( $value );

                    }elseif($key == 'section_category' || 
                            $key == 'section_post_slide_cat' || 
                            $key == 'section_category_1' || 
                            $key == 'section_category_2' || 
                            $key == 'section_category_3' || 
                            $key == 'section_category_4' || 
                            $key == 'category'
                        ){

                        $input_decoded[$boxes][$key] =  newsfort_sanitize_category( $value );

                    }else{

                        $input_decoded[$boxes][$key] = sanitize_text_field( $value );

                    }
                    
                }

            }
           
            return json_encode($input_decoded);

        }

        return $input;
    }
endif;

/** Sanitize Enable Disable Checkbox **/
function newsfort_sanitize_repeater_ed( $input ) {

    $valid_keys = array('yes','no');
    if ( in_array( $input , $valid_keys ) ) {
        return $input;
    }
    return '';

}

function newsfort_sanitize_home_sections( $input ) {

    $home_sections = array(

        'main-banner' => esc_html__('Main Banner','newsfort'),
        'slider-blocks' => esc_html__('Slider Block','newsfort'),
        'latest-posts-blocks' => esc_html__('Latest Posts Block','newsfort'),
        'carousel-blocks' => esc_html__('Carousel Block','newsfort'),
        'tiles-blocks' => esc_html__('Tiles Block','newsfort'),
        'lead-blocks' => esc_html__('Lead Block','newsfort'),
        'masonry-blocks' => esc_html__('Masonry Block','newsfort'),
        'banner-blocks-1' => esc_html__('Main Intro Block','newsfort'),
        'banner-blocks-2' => esc_html__('Banner Block Layout Two','newsfort'),
        'banner-blocks-3' => esc_html__('Banner Block Layout Three','newsfort'),
        'banner-blocks-4' => esc_html__('Banner Block Layout Four','newsfort'),
        'post-list-block' => esc_html__('Post List Block','newsfort'),
        'advertise-blocks' => esc_html__('Advertise Block','newsfort'),
        'home-widget-area' => esc_html__('Widgets Area Block','newsfort'),

    );
    if ( array_key_exists( $input , $home_sections ) ) {
        return $input;
    }
    return '';

}

/** Sanitize Category **/
function newsfort_sanitize_category( $input ) {

   $newsfort_post_category_list = newsfort_post_category_list();
    if ( array_key_exists( $input , $newsfort_post_category_list ) ) {
        return $input;
    }
    return '';

}

function newsfort_sanitize_bg_image_size( $input ) {

    $bg_image_size = array( 
                    'auto' => esc_html('Original','newsfort'),
                    'contain' => esc_html('Fit to Screen','newsfort'),
                    'cover' => esc_html('Fill Screen','newsfort'),
                );

    if ( array_key_exists( $input , $bg_image_size ) ) {
        return $input;
    }
    return '';

}

function newsfort_sanitize_ribbon_bg( $input ) {

    $ribbon_bg = array( 
                    '1' =>  array(
                                    'title' =>  esc_html__( 'Blue', 'newsfort' ),
                                    'color' =>  '#3061ff',
                                ),
                    '2' =>  array(
                                    'title' =>  esc_html__( 'Orange', 'newsfort' ),
                                    'color' =>  '#fa9000',
                                ),
                    '3' =>  array(
                                    'title' =>  esc_html__( 'Royal Blue', 'newsfort' ),
                                    'color' =>  '#00167a',
                                ),
                    '4' =>  array(
                                    'title' =>  esc_html__( 'Pink', 'newsfort' ),
                                    'color' =>  '#ff2d55',
                                ),
                );

    if ( array_key_exists( $input , $ribbon_bg ) ) {
        return $input;
    }
    return '';

}