<?php
/**
 * Widget FUnctions.
 *
 * @package NewsFort
 */
/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function newsfort_widgets_init(){

    $newsfort_default = newsfort_get_default_theme_options();
    $newsfort_header_layout = get_theme_mod('newsfort_header_layout', json_encode($newsfort_default['newsfort_header_layout']));

    register_sidebar(array(
        'name' => esc_html__('Sidebar', 'newsfort'),
        'id' => 'sidebar-1',
        'description' => esc_html__('Add widgets here.', 'newsfort'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h3 class="widget-title"><span>',
        'after_title' => '</span></h3>',
    ));

    register_sidebar(array(
        'name' => esc_html__('Header Advertisement One', 'newsfort'),
        'id' => 'newsfort-header-1',
        'description' => esc_html__('Add widgets here.', 'newsfort'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h3 class="widget-title"><span>',
        'after_title' => '</span></h3>',
    ));

    if( $newsfort_header_layout == 'layout-3' ){

        register_sidebar(array(
            'name' => esc_html__('Header Advertisement Two', 'newsfort'),
            'id' => 'newsfort-header-2',
            'description' => esc_html__('Add widgets here.', 'newsfort'),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));

    }

    $twp_newsfort_home_sections_7 = get_theme_mod('twp_newsfort_home_sections_7', json_encode($newsfort_default['twp_newsfort_home_sections_7']));
    $twp_newsfort_home_sections_7 = json_decode($twp_newsfort_home_sections_7);

    foreach( $twp_newsfort_home_sections_7 as $newsfort_home_section ){

        $home_section_type = isset( $newsfort_home_section->home_section_type ) ? $newsfort_home_section->home_section_type : '';

        switch( $home_section_type ){

            case 'home-widget-area':

                $ed_home_widget_area = isset( $newsfort_home_section->section_ed ) ? $newsfort_home_section->section_ed : '';

                if( $ed_home_widget_area == 'yes' ){

                    register_sidebar(array(
                        'name' => esc_html__('Homepage Main Widget Area', 'newsfort'),
                        'id' => 'newsfort-home-main-widget-area',
                        'description' => esc_html__('Add widgets here.', 'newsfort'),
                        'before_widget' => '<div id="%1$s" class="widget %2$s">',
                        'after_widget' => '</div>',
                        'before_title' => '<h2 class="block-title"><span>',
                        'after_title' => '</span></h2>',
                    ));

                    $enable_sidebar = isset( $newsfort_home_section->enable_sidebar ) ? $newsfort_home_section->enable_sidebar : '';

                    if( $enable_sidebar == 'yes' ){

                        register_sidebar(array(
                            'name' => esc_html__('Homepage Sidebar Widget Area', 'newsfort'),
                            'id' => 'newsfort-home-sidebar-widget-area',
                            'description' => esc_html__('Add widgets here.', 'newsfort'),
                            'before_widget' => '<div id="%1$s" class="widget %2$s">',
                            'after_widget' => '</div>',
                            'before_title' => '<h3 class="widget-title"><span>',
                            'after_title' => '</span></h3>',
                        ));

                    }

                }

                break;

            default:

                break;

        }

    }

    $newsfort_default = newsfort_get_default_theme_options();
    $footer_column_layout = absint(get_theme_mod('footer_column_layout', $newsfort_default['footer_column_layout']));

    for( $i = 0; $i < $footer_column_layout; $i++ ){

        if ($i == 0) {
            $count = esc_html__('One', 'newsfort');
        }
        if ($i == 1) {
            $count = esc_html__('Two', 'newsfort');
        }
        if ($i == 2) {
            $count = esc_html__('Three', 'newsfort');
        }

        register_sidebar(array(
            'name' => esc_html__('Footer Widget ', 'newsfort') . $count,
            'id' => 'newsfort-footer-widget-' . $i,
            'description' => esc_html__('Add widgets here.', 'newsfort'),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));

    }

}

add_action('widgets_init', 'newsfort_widgets_init');
require get_template_directory() . '/inc/widgets/widget-base.php';
require get_template_directory() . '/inc/widgets/author.php';
require get_template_directory() . '/inc/widgets/category.php';
require get_template_directory() . '/inc/widgets/recent-post.php';
require get_template_directory() . '/inc/widgets/social-link.php';
require get_template_directory() . '/inc/widgets/tab-posts.php';
require get_template_directory() . '/inc/widgets/carousel.php';
require get_template_directory() . '/inc/widgets/slider.php';
require get_template_directory() . '/inc/widgets/cat-posts.php';
require get_template_directory() . '/inc/widgets/list-posts.php';
require get_template_directory() . '/inc/widgets/post-grid.php';
require get_template_directory() . '/inc/widgets/tiles.php';
require get_template_directory() . '/inc/widgets/featured-category.php';