<?php
/**
 * Lead Blocks
 *
 * @package NewsFort
 */
if (!function_exists('newsfort_lead_block_section')):
    function newsfort_lead_block_section($newsfort_home_section, $repeat_times)
    {
        $section_category = esc_html(isset($newsfort_home_section->section_category) ? $newsfort_home_section->section_category : '');
        $home_section_title = isset($newsfort_home_section->home_section_title) ? $newsfort_home_section->home_section_title : '';
        $enable_wide_layout = esc_html(isset($newsfort_home_section->enable_wide_layout) ? $newsfort_home_section->enable_wide_layout : '');

        $class = 'wrapper';

        if ($enable_wide_layout == 'yes') {
            $class = 'wrapper-fluid';
        }
        
        $lead_post_query = new WP_Query(array('post_type' => 'post', 'posts_per_page' => 3, 'post__not_in' => get_option("sticky_posts"), 'category_name' => esc_html($section_category)));
        $ed_flip_column = esc_html(isset($newsfort_home_section->ed_flip_column) ? $newsfort_home_section->ed_flip_column : '');

        if( empty( $home_section_title ) && $section_category ){

            $catObj = get_category_by_slug( $section_category );
            if( isset($catObj->name) && $catObj->name ){
                $home_section_title = $catObj->name;
            }

        }

        if( $lead_post_query->have_posts() ): ?>

            <div id="block-<?php echo esc_attr($repeat_times); ?>" class="theme-block theme-block-lead">
                
                <div class="<?php echo $class; ?>">
                    <div class="column-row column-row-small">

                        <?php if( $home_section_title || $section_category ){ ?>

                            <div class="column column-12 column-sm-12">
                                <header class="block-title-wrapper">

                                    <?php if( $home_section_title ){ ?>

                                        <h2 class="block-title">
                                            <?php echo esc_html( $home_section_title ); ?>
                                        </h2>
                                    
                                    <?php } ?>

                                    <?php if( $section_category ){

                                        $catObj = get_category_by_slug( $section_category );
                                        if( isset($catObj->name) && $catObj->name ){
                                            $cat_title = $catObj->name;
                                        }
                                        $cat_link = get_category_link( $catObj->term_id ); ?>

                                        <div class="theme-heading-controls">
                                            <a href="<?php echo esc_url($cat_link); ?>" class="view-all-link">
                                                <span class="view-all-icon"><?php newsfort_the_theme_svg('plus'); ?></span>
                                                <span class="view-all-label"><?php echo esc_html_e('View All', 'newsfort'); ?></span>
                                            </a>
                                        </div>

                                    <?php } ?>

                                </header>

                            </div>

                        <?php }

                        while ($lead_post_query->have_posts()) {
                            $lead_post_query->the_post();
                            $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'medium_large');
                            $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>

                            <div class="column column-6 column-sm-12 mb-sm-15 <?php if ($ed_flip_column != 'yes') { ?>column-order-1<?php } else { ?>column-order-2<?php } ?>">
                                <article id="theme-post-<?php the_ID(); ?>" <?php post_class('post-thumb news-article news-article-bg'); ?>>

                                    <div class="data-bg data-bg-medium thumb-overlay thumb-overlay-darker img-hover-slide" data-background="<?php echo esc_url($featured_image); ?>">
                                        
                                        <?php
                                        $format = get_post_format(get_the_ID()) ?: 'standard';
                                        $icon = newsfort_post_format_icon($format);
                                        if (!empty($icon)) { ?>
                                            <span class="top-right-icon"><?php echo newsfort_svg_escape($icon); ?></span>
                                        <?php } ?>

                                        <a class="img-link" href="<?php the_permalink(); ?>" tabindex="0"></a>

                                        <div class="article-content article-content-overlay">
                                            <div class="entry-meta">
                                                <?php newsfort_entry_footer($cats = true, $tags = false, $edits = false, $text = false, $icon = false); ?>
                                            </div>
                                        </div>

                                    </div>

                                    <div class="article-content">

                                        <h3 class="entry-title entry-title-medium">
                                            <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a>
                                        </h3>

                                        <div class="entry-meta">
                                            <?php newsfort_posted_on(); ?>
                                            <?php newsfort_post_view_count(); ?>
                                            <?php newsfort_posted_by(); ?>
                                        </div>

                                        <div class="entry-content entry-content-muted entry-content-small">
                                            <?php
                                            if (has_excerpt()) {
                                                the_excerpt();
                                            } else {
                                                echo '<p>';
                                                echo esc_html( wp_trim_words( get_the_content(),30,'...' ) );
                                                echo '</p>';
                                            } ?>
                                        </div>

                                    </div>
                                </article>

                            </div>
                            <?php
                            break;
                        } ?>

                        <div class="column column-6 column-sm-12 <?php if ($ed_flip_column != 'yes') { ?>column-order-2<?php } else { ?>column-order-1<?php } ?>">
                            <div class="column-row column-row-small">

                                <?php
                                $i = 1;
                                while ($lead_post_query->have_posts()) {
                                    $lead_post_query->the_post();
                                    $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'newsfort-400-280');
                                    $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : '';
                                    ?>

                                    <div class="column column-6 column-xs-12 mb-xs-15">
                                        <div class="content-main content-main-bg">
                                            <div class="content-list">
                                                <article id="theme-post-<?php the_ID(); ?>" <?php post_class('news-article'); ?>>

                                                    <?php if ($featured_image) { ?>
                                                        <div class="post-thumbnail">
                                                            <div class="img-hover-scale">

                                                                <?php
                                                                $format = get_post_format(get_the_ID()) ?: 'standard';
                                                                $icon = newsfort_post_format_icon($format);
                                                                if (!empty($icon)) { ?>
                                                                    <span class="top-right-icon"><?php echo newsfort_svg_escape($icon); ?></span>
                                                                <?php } ?>

                                                                <a href="<?php the_permalink(); ?>" tabindex="0">
                                                                    <img title="<?php the_title_attribute(); ?>" alt="<?php the_title_attribute(); ?>" src="<?php echo esc_url($featured_image); ?>">
                                                                </a>

                                                                <div class="article-content article-content-overlay">
                                                                    <div class="entry-meta">
                                                                        <?php newsfort_entry_footer($cats = true, $tags = false, $edits = false, $text = false, $icon = false); ?>
                                                                    </div>
                                                                </div>

                                                            </div>
                                                        </div>
                                                    <?php } ?>

                                                    <div class="article-content">

                                                        <h3 class="entry-title entry-title-small">
                                                            <a href="<?php the_permalink(); ?>" rel="bookmark"><?php the_title(); ?></a>
                                                        </h3>

                                                        <div class="entry-meta">
                                                            <?php newsfort_posted_on(); ?>
                                                            <?php newsfort_post_view_count(); ?>
                                                        </div>

                                                        <div class="entry-content entry-content-muted entry-content-small">
                                                            <?php
                                                            if (has_excerpt()) {
                                                                the_excerpt();
                                                            } else {
                                                                echo '<p>';
                                                                echo esc_html( wp_trim_words( get_the_content(),20,'...' ) );
                                                                echo '</p>';
                                                            } ?>
                                                        </div>

                                                    </div>
                                                    
                                                </article>
                                            </div>
                                        </div>
                                    </div>

                                    <?php
                                    $i++;
                                } ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <?php
            wp_reset_postdata();
        endif;
    }
endif;