<?php
/**
 * Lead Blocks
 *
 * @package NewsFort
 */
if (!function_exists('newsfort_masonry_block_section')):
    function newsfort_masonry_block_section($newsfort_home_section, $repeat_times){

        $newsfort_default = newsfort_get_default_theme_options();
        $ed_wide_layout = esc_html( isset($newsfort_home_section->ed_wide_layout) ? $newsfort_home_section->ed_wide_layout : '');
        $section_category = esc_html( isset($newsfort_home_section->section_category) ? $newsfort_home_section->section_category : '');
        $home_section_title = esc_html(isset($newsfort_home_section->home_section_title) ? $newsfort_home_section->home_section_title : '');
        $video_autoplay = esc_html(isset($newsfort_home_section->section_video_autoplay) ? $newsfort_home_section->section_video_autoplay : '');
        $masonry_post_query = new WP_Query( array( 'post_type' => 'post','posts_per_page' => 8,'post__not_in' => get_option("sticky_posts"), 'category_name' => esc_html( $section_category ) ) );

        if( $ed_wide_layout == 'yes' ){

            $container_class = 'wrapper-fluid';
            $column_class = 'column-3';

        }else{

            $container_class = 'wrapper';
            $column_class = 'column-4';

        }

        if( empty( $home_section_title ) && $section_category ){

            $catObj = get_category_by_slug( $section_category );
            if( isset($catObj->name) && $catObj->name ){
                $home_section_title = $catObj->name;
            }

        }

        if( $masonry_post_query ->have_posts() ): ?>

            <div id="block-<?php echo esc_attr( $repeat_times ); ?>" repeat-time="<?php echo esc_attr( 'repeat-time-'.$repeat_times ); ?>" class="theme-block theme-block-masonry <?php echo esc_attr( 'repeat-time-'.$repeat_times ); ?>">
                <div class="<?php echo esc_attr( $container_class ); ?>">

                    <?php if( $home_section_title || $section_category ){ ?>

                        <div class="column-row">
                            <div class="column column-12 column-sm-12">
                                <header class="block-title-wrapper">

                                    <?php if( $home_section_title ){ ?>

                                        <h2 class="block-title">
                                            <?php echo esc_html( $home_section_title ); ?>
                                        </h2>
                                    
                                    <?php } ?>

                                    <?php if( $section_category ){

                                        $catObj = get_category_by_slug( $section_category );
                                        if( isset($catObj->name) && $catObj->name ){
                                            $cat_title = $catObj->name;
                                        }
                                        $cat_link = get_category_link( $catObj->term_id ); ?>

                                        <div class="theme-heading-controls">
                                            <a href="<?php echo esc_url($cat_link); ?>" class="view-all-link">
                                                <span class="view-all-icon"><?php newsfort_the_theme_svg('plus'); ?></span>
                                                <span class="view-all-label"><?php echo esc_html_e('View All', 'newsfort'); ?></span>
                                            </a>
                                        </div>

                                    <?php } ?>

                                </header>

                            </div>
                        </div>

                    <?php } ?>

                    <div class="column-row all-item-content">

                        <?php
                        while( $masonry_post_query ->have_posts() ){
                            $masonry_post_query ->the_post(); ?>

                            <div class="column <?php echo $column_class; ?> column-sm-6 column-xs-12 twp-masonary-item">

                                <?php 
                                if( get_post_format() == 'video' ){

                                    $video_autoplay = esc_attr( get_post_meta(get_the_ID(), 'twp_video_autoplay', true) );
                                    if( $video_autoplay == '' || $video_autoplay == 'global' ){

                                        $video_autoplay = isset($newsfort_home_section->section_video_autoplay) ? $newsfort_home_section->section_video_autoplay : '';
                                        $video_autoplay_1 = isset($newsfort_home_section->section_video_autoplay) ? $newsfort_home_section->section_video_autoplay : '';

                                        if( $video_autoplay == '' || $video_autoplay == 'global' ){
                                            $video_autoplay = get_theme_mod( 'ed_autoplay', $newsfort_default['ed_autoplay'] );
                                        }

                                    }

                                    $ratio_value = get_post_meta( get_the_ID(), 'twp_aspect_ratio', true );
                                    if( $ratio_value == '' || $ratio_value == 'global' ){
                                        
                                        $ratio_value = isset( $newsfort_home_section->section_video_ratio ) ? $newsfort_home_section->section_video_ratio : '';
                                        $ratio_value_1 = isset( $newsfort_home_section->section_video_ratio ) ? $newsfort_home_section->section_video_ratio : '';

                                        if( $ratio_value == '' || $ratio_value == 'global' ){
                                            $ratio_value = get_theme_mod( 'post_video_aspect_ration', $newsfort_default['post_video_aspect_ration'] );
                                        }

                                    }

                                    newsfort_video_content_render( $class1 = 'theme-post', $class2 = 'video-id-2', $class3 = 'video-main-wraper-2', $ratio_value, $video_autoplay );

                                }else{
                                    
                                    get_template_part( 'template-parts/content', get_post_format() );

                                } ?>

                            </div>

                        <?php } ?>

                    </div>

                    <div class="ajax-content-before-load" style="display: none;"></div>

                    <div class="loadmore-area hide-no-js">
                        <button video-autoplay="<?php echo esc_attr( $video_autoplay_1 ); ?>" video-ratio="<?php echo esc_attr( $ratio_value_1 ); ?>" class-1="<?php echo $column_class; ?>" type="button" paged_current="2" section_category="<?php echo esc_attr( $section_category ); ?>" class="btn-loadmore">
                            <span class="loadmore"><?php echo esc_html('Load More Posts','newsfort'); ?></span>
                        </button>
                    </div>

                </div>
            </div>

        <?php
        wp_reset_postdata();
        endif;

    }
endif;