<?php
/**
 * Banner Blocks Four
 *
 * @package NewsFort
 */

if (!function_exists('newsfort_post_list_block_section')):

    function newsfort_post_list_block_section($newsfort_home_section, $repeat_times){

        $section_category = esc_html(isset($newsfort_home_section->section_category) ? $newsfort_home_section->section_category : '');
        $home_section_title = esc_html(isset($newsfort_home_section->home_section_title) ? $newsfort_home_section->home_section_title : '3');
        $enable_wide_layout = esc_html(isset($newsfort_home_section->enable_wide_layout) ? $newsfort_home_section->enable_wide_layout : '');

        $class = 'wrapper';

        if ($enable_wide_layout == 'yes') {
            $class = 'wrapper-fluid';
        }
        
        if( empty( $home_section_title ) && $section_category ){

            $catObj = get_category_by_slug( $section_category );
            if( isset($catObj->name) && $catObj->name ){
                $home_section_title = $catObj->name;
            }

        }
        
        $section_query = new WP_Query( array('post_type' => 'post', 'posts_per_page' => 9,'post__not_in' => get_option("sticky_posts"), 'category_name' => esc_html( $section_category ) ) );

        if( $section_query->have_posts() ): ?>

            <div id="block-<?php echo esc_attr( $repeat_times ); ?>" class="theme-block theme-block-elements theme-post-list-block">
                
                <div class="<?php echo $class; ?>">
                    <div class="column-row">

                         <?php if( $home_section_title || $section_category ){ ?>

                                <div class="column column-12 column-sm-12">
                                    <header class="block-title-wrapper">

                                        <?php if( $home_section_title ){ ?>

                                            <h2 class="block-title">
                                                <?php echo esc_html( $home_section_title ); ?>
                                            </h2>
                                        
                                        <?php } ?>

                                        <?php if( $section_category ){

                                            $catObj = get_category_by_slug( $section_category );
                                            if( isset($catObj->name) && $catObj->name ){
                                                $cat_title = $catObj->name;
                                            }
                                            $cat_link = get_category_link( $catObj->term_id ); ?>

                                            <div class="theme-heading-controls">
                                                <a href="<?php echo esc_url($cat_link); ?>" class="view-all-link">
                                                    <span class="view-all-icon"><?php newsfort_the_theme_svg('plus'); ?></span>
                                                    <span class="view-all-label"><?php echo esc_html_e('View All', 'newsfort'); ?></span>
                                                </a>
                                            </div>

                                        <?php } ?>

                                    </header>

                                </div>

                            <?php } ?>


                        <div class="column column-12">

                           
                            <div class="column-row">
                                <?php
                                while( $section_query->have_posts() ):
                                    $section_query->the_post();

                                    $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'thumbnail');
                                    $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>

                                    <div class="column column-4 column-sm-6 column-xs-12">
                                        <article id="theme-post-<?php the_ID(); ?>" <?php post_class( 'news-article  mb-20 news-article-bg' ); ?>>
                                            <div class="column-row column-row-small">

                                                <?php if( $featured_image ){ ?>

                                                    <div class="column column-4">
                                                        <div class="post-thumbnail">
                                                            <div class="img-hover-scale">
                                                                <?php
                                                                $format = get_post_format(get_the_ID()) ?: 'standard';
                                                                $icon = newsfort_post_format_icon($format);
                                                                if (!empty($icon)) { ?>
                                                                    <span class="top-right-icon"><?php echo newsfort_svg_escape( $icon ); ?></span>
                                                                <?php } ?>

                                                                <a href="<?php the_permalink(); ?>" tabindex="0">
                                                                    <img title="<?php the_title_attribute(); ?>" alt="<?php the_title_attribute(); ?>" src="<?php echo esc_url($featured_image); ?>">
                                                                </a>
                                                            </div>
                                                        </div>
                                                    </div>

                                                <?php } ?>

                                                <div class="column column-<?php if(  $featured_image[0] ){ ?>8<?php }else{ ?>12<?php } ?>">
                                                    <div class="article-content">
                                                        <h3 class="entry-title entry-title-xsmall">
                                                            <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a>
                                                        </h3>
                                                        <div class="entry-meta">
                                                            <div class="entry-meta-item entry-meta-date">
                                                                <div class="entry-meta-wrapper">
                                                                    <?php newsfort_posted_on(); ?>
                                                                    <?php newsfort_post_view_count(); ?>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>

                                            </div>
                                        </article>
                                    </div>

                                <?php endwhile;
                                wp_reset_postdata(); ?>

                            </div>

                        </div>
                    </div>
                </div>
            </div>

        <?php
        endif;

    }
endif;